@@ -6,21 +6,23 @@
 gboolean can_quit = FALSE;
 
 /* eos will be called when the src element has an end of stream */
-void 
-eos (GstElement *src, gpointer data) 
+void
+eos (GstElement * src, gpointer data)
 {
   GstThread *thread = GST_THREAD (data);
+
   g_print ("have eos, quitting\n");
 
   /* stop the bin */
   gst_element_set_state (GST_ELEMENT (thread), GST_STATE_NULL);
 
-  while (!can_quit) /* waste cycles */ ;
+  while (!can_quit)             /* waste cycles */
+    ;
   gst_main_quit ();
 }
 
-int 
-main (int argc, char *argv[]) 
+int
+main (int argc, char *argv[])
 {
   GstElement *filesrc, *decoder, *audiosink;
   GstElement *thread;
@@ -40,8 +42,7 @@ main (int argc, char *argv[])
   filesrc = gst_element_factory_make ("filesrc", "disk_source");
   g_assert (filesrc != NULL);
   g_object_set (G_OBJECT (filesrc), "location", argv[1], NULL);
-  g_signal_connect (G_OBJECT (filesrc), "eos",
-                     G_CALLBACK (eos), thread);
+  g_signal_connect (G_OBJECT (filesrc), "eos", G_CALLBACK (eos), thread);
 
   /* create an ogg decoder */
   decoder = gst_element_factory_make ("vorbisfile", "decoder");
@@ -61,7 +62,7 @@ main (int argc, char *argv[])
 
   /* do whatever you want here, the thread will be playing */
   g_print ("thread is playing\n");
-  
+
   can_quit = TRUE;
   gst_main ();
 
@@ -69,4 +70,5 @@ main (int argc, char *argv[])
 
   exit (0);
 }
+
 /* example-end threads.c */
