@@ -50,6 +50,11 @@
 #include "gstspideridentity.h"
 #include "gstsearchfuncs.h"
 
+static GstElementDetails gst_spider_details = GST_ELEMENT_DETAILS ("Spider",
+    "Generic",
+    "Automatically link sinks and sources",
+    "Benjamin Otte <in7y118@public.uni-hamburg.de>");
+
 GST_DEBUG_CATEGORY (gst_spider_debug);
 #define GST_CAT_DEFAULT gst_spider_debug
 
@@ -138,6 +143,7 @@ gst_spider_get_type (void)
       0,
       (GInstanceInitFunc) gst_spider_init,
     };
+
     spider_type =
         g_type_register_static (GST_TYPE_BIN, "GstSpider", &spider_info, 0);
   }
@@ -195,6 +201,7 @@ gst_spider_dispose (GObject * object)
 
   spider = GST_SPIDER (object);
   g_list_free (spider->factories);
+  spider->factories = NULL;
 
   ((GObjectClass *) parent_class)->dispose (object);
 }
@@ -357,8 +364,6 @@ gst_spider_link_reset (GstSpiderConnection * conn, GstElement * to)
 static void
 gst_spider_link_add (GstSpiderConnection * conn, GstElement * element)
 {
-  gst_object_ref ((GstObject *) element);
-  gst_object_sink ((GstObject *) element);
   conn->path = g_list_prepend (conn->path, element);
   conn->current = element;
 }
@@ -427,9 +432,8 @@ gst_spider_identity_plug (GstSpiderIdentity * ident)
       while (factories) {
         if ((padtemp =
                 gst_autoplug_can_connect_src (factories->data, src_caps))) {
-          const GstCaps *caps = gst_pad_template_get_caps (padtemp);
-
-          GST_DEBUG ("can connect src to pad template: %" GST_PTR_FORMAT, caps);
+          GST_DEBUG ("can connect src to pad template: %" GST_PTR_FORMAT,
+              gst_pad_template_get_caps (padtemp));
           found = TRUE;
         }
         factories = factories->next;
@@ -727,11 +731,6 @@ gst_spider_plug_from_srcpad (GstSpiderConnection * conn, GstPad * srcpad)
   return result;
 }
 
-GstElementDetails gst_spider_details = GST_ELEMENT_DETAILS ("Spider",
-    "Generic",
-    "Automatically link sinks and sources",
-    "Benjamin Otte <in7y118@public.uni-hamburg.de>");
-
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
