@@ -31,7 +31,9 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
+#ifdef HAVE_MMAP
 #include <sys/mman.h>
+#endif
 #include <errno.h>
 #include <string.h>
 
@@ -112,6 +114,7 @@ gst_filesrc_get_event_mask (GstPad * pad)
     {GST_EVENT_SIZE, 0},
     {0, 0}
   };
+
   return masks;
 }
 
@@ -123,6 +126,7 @@ gst_filesrc_get_query_types (GstPad * pad)
     GST_QUERY_POSITION,
     0
   };
+
   return types;
 }
 
@@ -133,6 +137,7 @@ gst_filesrc_get_formats (GstPad * pad)
     GST_FORMAT_BYTES,
     0,
   };
+
   return formats;
 }
 
@@ -162,6 +167,7 @@ _do_init (GType filesrc_type)
     NULL,
     NULL
   };
+
   g_type_add_interface_static (filesrc_type, GST_TYPE_URI_HANDLER,
       &urihandler_info);
   GST_DEBUG_CATEGORY_INIT (gst_filesrc_debug, "filesrc", 0, "filesrc element");
@@ -224,11 +230,14 @@ gst_filesrc_init (GstFileSrc * src)
   gst_pad_set_formats_function (src->srcpad, gst_filesrc_get_formats);
   gst_element_add_pad (GST_ELEMENT (src), src->srcpad);
 
+#ifdef HAVE_MMAP
   src->pagesize = getpagesize ();
+#endif
 
   src->filename = NULL;
   src->fd = 0;
   src->filelen = 0;
+  src->uri = NULL;
 
   src->curoffset = 0;
   src->block_size = DEFAULT_BLOCKSIZE;
@@ -247,12 +256,14 @@ gst_filesrc_dispose (GObject * object)
 
   src = GST_FILESRC (object);
 
-  G_OBJECT_CLASS (parent_class)->dispose (object);
+  g_free (src->filename);
+  g_free (src->uri);
 
-  if (src->filename)
-    g_free (src->filename);
-  if (src->uri)
-    g_free (src->uri);
+  /* dispose may be called multiple times */
+  src->filename = NULL;
+  src->uri = NULL;
+
+  G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
 static gboolean
@@ -262,10 +273,9 @@ gst_filesrc_set_location (GstFileSrc * src, const gchar * location)
   if (GST_STATE (src) != GST_STATE_READY && GST_STATE (src) != GST_STATE_NULL)
     return FALSE;
 
-  if (src->filename)
-    g_free (src->filename);
-  if (src->uri)
-    g_free (src->uri);
+  g_free (src->filename);
+  g_free (src->uri);
+
   /* clear the filename if we get a NULL (is that possible?) */
   if (location == NULL) {
     src->filename = NULL;
@@ -351,6 +361,7 @@ gst_filesrc_get_property (GObject * object, guint prop_id, GValue * value,
   }
 }
 
+#ifdef HAVE_MMAP
 static void
 gst_filesrc_free_parent_mmap (GstBuffer * buf)
 {
@@ -371,7 +382,9 @@ gst_filesrc_free_parent_mmap (GstBuffer * buf)
 
   GST_BUFFER_DATA (buf) = NULL;
 }
+#endif
 
+#ifdef HAVE_MMAP
 static GstBuffer *
 gst_filesrc_map_region (GstFileSrc * src, off_t offset, size_t size)
 {
@@ -419,7 +432,9 @@ gst_filesrc_map_region (GstFileSrc * src, off_t offset, size_t size)
 
   return buf;
 }
+#endif
 
+#ifdef HAVE_MMAP
 static GstBuffer *
 gst_filesrc_map_small_region (GstFileSrc * src, off_t offset, size_t size)
 {
@@ -451,7 +466,9 @@ gst_filesrc_map_small_region (GstFileSrc * src, off_t offset, size_t size)
 
   return gst_filesrc_map_region (src, offset, size);
 }
+#endif
 
+#ifdef HAVE_MMAP
 /**
  * gst_filesrc_get_mmap:
  * @pad: #GstPad to push a buffer from
@@ -587,6 +604,7 @@ gst_filesrc_get_mmap (GstFileSrc * src)
   src->curoffset += GST_BUFFER_SIZE (buf);
   return buf;
 }
+#endif
 
 static GstBuffer *
 gst_filesrc_get_read (GstFileSrc * src)
@@ -663,12 +681,15 @@ gst_filesrc_get (GstPad * pad)
       return GST_DATA (gst_event_new (GST_EVENT_EOS));
     }
   }
-
+#ifdef HAVE_MMAP
   if (src->using_mmap) {
     return GST_DATA (gst_filesrc_get_mmap (src));
   } else {
     return GST_DATA (gst_filesrc_get_read (src));
   }
+#else
+  return GST_DATA (gst_filesrc_get_read (src));
+#endif
 }
 
 /* TRUE if the filesize of the file was updated */
@@ -730,13 +751,15 @@ gst_filesrc_open_file (GstFileSrc * src)
     /* find the file length */
     src->filelen = stat_results.st_size;
 
+    src->using_mmap = FALSE;
+#ifdef HAVE_MMAP
     /* allocate the first mmap'd region */
     src->mapbuf = gst_filesrc_map_region (src, 0, src->mapsize);
-    if (src->mapbuf == NULL) {
-      src->using_mmap = FALSE;
-    } else {
+    if (src->mapbuf != NULL) {
       src->using_mmap = TRUE;
     }
+#endif
+
 
     src->curoffset = 0;
 
@@ -854,8 +877,9 @@ gst_filesrc_srcpad_event (GstPad * pad, GstEvent * event)
 
       switch (GST_EVENT_SEEK_METHOD (event)) {
         case GST_SEEK_METHOD_SET:
-          if (offset > src->filelen && (!gst_filesrc_check_filesize (src)
-                  || offset > src->filelen)) {
+          if (offset < 0 ||
+              (offset > src->filelen && (!gst_filesrc_check_filesize (src)
+                      || offset > src->filelen))) {
             goto error;
           }
           src->curoffset = offset;
@@ -923,6 +947,7 @@ static gchar **
 gst_filesrc_uri_get_protocols (void)
 {
   static gchar *protocols[] = { "file", NULL };
+
   return protocols;
 }
 static const gchar *
