@@ -29,27 +29,24 @@
 
 #include "gstshaper.h"
 
-GST_DEBUG_CATEGORY (gst_shaper_debug);
+GST_DEBUG_CATEGORY_STATIC (gst_shaper_debug);
 #define GST_CAT_DEFAULT gst_shaper_debug
 
-GstElementDetails gst_shaper_details = {
-  "Shaper",
-  "Generic",
-  "LGPL",
-  "Synchronizes streams on different pads",
-  VERSION,
-  "Wim Taymans <wim.taymans@chello.be>",
-  "(C) 2003",
-};
+GstElementDetails gst_shaper_details = GST_ELEMENT_DETAILS ("Shaper",
+    "Generic",
+    "Synchronizes streams on different pads",
+    "Wim Taymans <wim.taymans@chello.be>");
 
 
 /* Shaper signals and args */
-enum {
+enum
+{
   /* FILL ME */
   LAST_SIGNAL
 };
 
-enum {
+enum
+{
   ARG_0,
   ARG_POLICY,
   ARG_SILENT,
@@ -58,24 +55,20 @@ enum {
 
 typedef struct
 {
-  GstPad 	*sinkpad;
-  GstPad 	*srcpad;
-  GstBuffer	*buffer;
+  GstPad *sinkpad;
+  GstPad *srcpad;
+  GstBuffer *buffer;
 } GstShaperConnection;
 
-GST_PAD_TEMPLATE_FACTORY (shaper_src_factory,
-  "src%d",
-  GST_PAD_SRC,
-  GST_PAD_SOMETIMES,
-  GST_CAPS_ANY
-);
+GstStaticPadTemplate shaper_src_template = GST_STATIC_PAD_TEMPLATE ("src%d",
+    GST_PAD_SRC,
+    GST_PAD_SOMETIMES,
+    GST_STATIC_CAPS_ANY);
 
-GST_PAD_TEMPLATE_FACTORY (shaper_sink_factory,
-  "sink%d",
-  GST_PAD_SINK,
-  GST_PAD_REQUEST,
-  GST_CAPS_ANY
-);
+GstStaticPadTemplate shaper_sink_template = GST_STATIC_PAD_TEMPLATE ("sink%d",
+    GST_PAD_SINK,
+    GST_PAD_REQUEST,
+    GST_STATIC_CAPS_ANY);
 
 #define GST_TYPE_SHAPER_POLICY (gst_shaper_policy_get_type())
 static GType
@@ -83,105 +76,93 @@ gst_shaper_policy_get_type (void)
 {
   static GType shaper_policy_type = 0;
   static GEnumValue shaper_policy[] = {
-    { SHAPER_POLICY_TIMESTAMPS,         "1", "sync on timestamps"},
-    { SHAPER_POLICY_BUFFERSIZE,         "2", "sync on buffer size"},
+    {SHAPER_POLICY_TIMESTAMPS, "1", "sync on timestamps"},
+    {SHAPER_POLICY_BUFFERSIZE, "2", "sync on buffer size"},
     {0, NULL, NULL},
   };
   if (!shaper_policy_type) {
-    shaper_policy_type = g_enum_register_static ("GstShaperPolicy", shaper_policy);
+    shaper_policy_type =
+        g_enum_register_static ("GstShaperPolicy", shaper_policy);
   }
   return shaper_policy_type;
 }
 
-static void 	gst_shaper_class_init		(GstShaperClass *klass);
-static void 	gst_shaper_init			(GstShaper *shaper);
+#define _do_init(bla) \
+    GST_DEBUG_CATEGORY_INIT (gst_shaper_debug, "shaper", 0, "shaper element");
 
-static void 	gst_shaper_set_property		(GObject *object, guint prop_id, 
-						 const GValue *value, GParamSpec *pspec);
-static void 	gst_shaper_get_property		(GObject *object, guint prop_id, 
-						 GValue *value, GParamSpec *pspec);
+GST_BOILERPLATE_FULL (GstShaper, gst_shaper, GstElement, GST_TYPE_ELEMENT,
+    _do_init);
 
-static GstPad* 	gst_shaper_request_new_pad 	(GstElement *element, GstPadTemplate *templ, 
-						 const gchar *unused);
+static void gst_shaper_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec);
+static void gst_shaper_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec);
 
-static void 	gst_shaper_loop			(GstElement *element);
+static GstPad *gst_shaper_request_new_pad (GstElement * element,
+    GstPadTemplate * templ, const gchar * unused);
 
-static GstElementClass *parent_class = NULL;
-/* static guint gst_shaper_signals[LAST_SIGNAL] = { 0 }; */
+static void gst_shaper_loop (GstElement * element);
 
-GType
-gst_shaper_get_type (void) 
+
+static void
+gst_shaper_base_init (gpointer g_class)
 {
-  static GType shaper_type = 0;
+  GstElementClass *gstelement_class = GST_ELEMENT_CLASS (g_class);
 
-  if (!shaper_type) {
-    static const GTypeInfo shaper_info = {
-      sizeof(GstShaperClass),      NULL,
-      NULL,
-      (GClassInitFunc)gst_shaper_class_init,
-      NULL,
-      NULL,
-      sizeof(GstShaper),
-      0,
-      (GInstanceInitFunc)gst_shaper_init,
-    };
-    shaper_type = g_type_register_static (GST_TYPE_ELEMENT, "GstShaper", &shaper_info, 0);
-  }
-  return shaper_type;
+  gst_element_class_set_details (gstelement_class, &gst_shaper_details);
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&shaper_src_template));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&shaper_sink_template));
 }
 
-static void 
-gst_shaper_class_init (GstShaperClass *klass) 
+static void
+gst_shaper_class_init (GstShaperClass * klass)
 {
   GObjectClass *gobject_class;
   GstElementClass *gstelement_class;
 
-  gobject_class = (GObjectClass*) klass;
-  gstelement_class = (GstElementClass*) klass;
+  gobject_class = (GObjectClass *) klass;
+  gstelement_class = (GstElementClass *) klass;
 
-  parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_POLICY,
-    g_param_spec_enum ("policy", "Policy", "Shaper policy",
-                       GST_TYPE_SHAPER_POLICY, SHAPER_POLICY_TIMESTAMPS, G_PARAM_READWRITE));
+      g_param_spec_enum ("policy", "Policy", "Shaper policy",
+          GST_TYPE_SHAPER_POLICY, SHAPER_POLICY_TIMESTAMPS, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_SILENT,
-    g_param_spec_boolean ("silent", "silent", "silent",
-                          FALSE, G_PARAM_READWRITE)); 
+      g_param_spec_boolean ("silent", "silent", "silent",
+          FALSE, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_LAST_MESSAGE,
-    g_param_spec_string ("last-message", "last-message", "last-message",
-                         NULL, G_PARAM_READABLE)); 
+      g_param_spec_string ("last-message", "last-message", "last-message",
+          NULL, G_PARAM_READABLE));
 
-  gobject_class->set_property = GST_DEBUG_FUNCPTR (gst_shaper_set_property);  
+  gobject_class->set_property = GST_DEBUG_FUNCPTR (gst_shaper_set_property);
   gobject_class->get_property = GST_DEBUG_FUNCPTR (gst_shaper_get_property);
 
-  gstelement_class->request_new_pad = GST_DEBUG_FUNCPTR (gst_shaper_request_new_pad);
+  gstelement_class->request_new_pad =
+      GST_DEBUG_FUNCPTR (gst_shaper_request_new_pad);
 }
 
-static GstBufferPool*
-gst_shaper_get_bufferpool (GstPad *pad)
-{
-  GstShaperConnection *connection;
-
-  connection = gst_pad_get_element_private (pad);
-
-  return gst_pad_get_bufferpool (connection->srcpad);
-}
-
-static GstCaps*
-gst_shaper_getcaps (GstPad *pad, GstCaps *caps)
+static GstCaps *
+gst_shaper_getcaps (GstPad * pad)
 {
   GstPad *otherpad;
   GstShaperConnection *connection;
 
   connection = gst_pad_get_element_private (pad);
 
-  otherpad = (pad == connection->srcpad ? connection->sinkpad : connection->srcpad);
+  otherpad =
+      (pad == connection->srcpad ? connection->sinkpad : connection->srcpad);
 
-  return gst_pad_get_allowed_caps (otherpad);
+  if (GST_PAD_PEER (otherpad)) {
+    return gst_pad_get_caps (GST_PAD_PEER (otherpad));
+  } else {
+    return gst_caps_new_any ();
+  }
 }
 
-static GList*
-gst_shaper_get_internal_link (GstPad *pad)
+static GList *
+gst_shaper_get_internal_link (GstPad * pad)
 {
   GList *res = NULL;
   GstShaperConnection *connection;
@@ -189,7 +170,8 @@ gst_shaper_get_internal_link (GstPad *pad)
 
   connection = gst_pad_get_element_private (pad);
 
-  otherpad = (pad == connection->srcpad ? connection->sinkpad : connection->srcpad);
+  otherpad =
+      (pad == connection->srcpad ? connection->sinkpad : connection->srcpad);
 
   res = g_list_prepend (res, otherpad);
 
@@ -197,20 +179,21 @@ gst_shaper_get_internal_link (GstPad *pad)
 }
 
 static GstPadLinkReturn
-gst_shaper_link (GstPad *pad, GstCaps *caps)
+gst_shaper_link (GstPad * pad, const GstCaps * caps)
 {
   GstPad *otherpad;
   GstShaperConnection *connection;
 
   connection = gst_pad_get_element_private (pad);
 
-  otherpad = (pad == connection->srcpad ? connection->sinkpad : connection->srcpad);
+  otherpad =
+      (pad == connection->srcpad ? connection->sinkpad : connection->srcpad);
 
-  return gst_pad_proxy_link (otherpad, caps);
+  return gst_pad_try_set_caps (otherpad, caps);
 }
 
-static GstShaperConnection*
-gst_shaper_create_connection (GstShaper *shaper)
+static GstShaperConnection *
+gst_shaper_create_connection (GstShaper * shaper)
 {
   GstShaperConnection *connection;
   gchar *padname;
@@ -220,20 +203,25 @@ gst_shaper_create_connection (GstShaper *shaper)
   connection = g_new0 (GstShaperConnection, 1);
 
   padname = g_strdup_printf ("sink%d", shaper->nconnections);
-  connection->sinkpad = gst_pad_new_from_template (shaper_sink_factory (), padname);
+  connection->sinkpad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&shaper_sink_template), padname);
   g_free (padname);
-  gst_pad_set_bufferpool_function (connection->sinkpad, gst_shaper_get_bufferpool);
   gst_pad_set_getcaps_function (connection->sinkpad, gst_shaper_getcaps);
-  gst_pad_set_internal_link_function (connection->sinkpad, gst_shaper_get_internal_link);
+  gst_pad_set_internal_link_function (connection->sinkpad,
+      gst_shaper_get_internal_link);
   gst_pad_set_link_function (connection->sinkpad, gst_shaper_link);
   gst_pad_set_element_private (connection->sinkpad, connection);
   gst_element_add_pad (GST_ELEMENT (shaper), connection->sinkpad);
 
   padname = g_strdup_printf ("src%d", shaper->nconnections);
-  connection->srcpad = gst_pad_new_from_template (shaper_src_factory (), padname);
+  connection->srcpad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&shaper_src_template), padname);
   g_free (padname);
   gst_pad_set_getcaps_function (connection->srcpad, gst_shaper_getcaps);
-  gst_pad_set_internal_link_function (connection->srcpad, gst_shaper_get_internal_link);
+  gst_pad_set_internal_link_function (connection->srcpad,
+      gst_shaper_get_internal_link);
   gst_pad_set_link_function (connection->srcpad, gst_shaper_link);
   gst_pad_set_element_private (connection->srcpad, connection);
   gst_element_add_pad (GST_ELEMENT (shaper), connection->srcpad);
@@ -243,8 +231,9 @@ gst_shaper_create_connection (GstShaper *shaper)
   return connection;
 }
 
-static GstPad*
-gst_shaper_request_new_pad (GstElement *element, GstPadTemplate *templ, const gchar *unused)
+static GstPad *
+gst_shaper_request_new_pad (GstElement * element, GstPadTemplate * templ,
+    const gchar * unused)
 {
   GstShaper *shaper = GST_SHAPER (element);
   GstShaperConnection *connection;
@@ -254,8 +243,8 @@ gst_shaper_request_new_pad (GstElement *element, GstPadTemplate *templ, const gc
   return connection->sinkpad;
 }
 
-static void 
-gst_shaper_init (GstShaper *shaper) 
+static void
+gst_shaper_init (GstShaper * shaper)
 {
   gst_element_set_loop_function (GST_ELEMENT (shaper), gst_shaper_loop);
 
@@ -266,8 +255,8 @@ gst_shaper_init (GstShaper *shaper)
   shaper->last_message = NULL;
 }
 
-static void 
-gst_shaper_loop (GstElement *element) 
+static void
+gst_shaper_loop (GstElement * element)
 {
   GstShaper *shaper;
   GSList *connections;
@@ -290,32 +279,30 @@ gst_shaper_loop (GstElement *element)
 
       /* events are simply pushed ASAP */
       if (GST_IS_EVENT (buffer)) {
-	/* save event type as it will be unreffed after the next push */
-	GstEventType type = GST_EVENT_TYPE (buffer);
+        /* save event type as it will be unreffed after the next push */
+        GstEventType type = GST_EVENT_TYPE (buffer);
 
-	gst_pad_push (connection->srcpad, GST_DATA (buffer));
+        gst_pad_push (connection->srcpad, GST_DATA (buffer));
 
-	switch (type) {
-          /* on EOS we disable the pad so that we don't pull on
-	   * it again and never get more data */
+        switch (type) {
+            /* on EOS we disable the pad so that we don't pull on
+             * it again and never get more data */
           case GST_EVENT_EOS:
-	    gst_pad_set_active (connection->sinkpad, FALSE);
-	    break;
-	  default:
-	    break;
-	}
-      }
-      else {
-	/* we store the buffer */
-	connection->buffer = buffer;
+            gst_pad_set_active (connection->sinkpad, FALSE);
+            break;
+          default:
+            break;
+        }
+      } else {
+        /* we store the buffer */
+        connection->buffer = buffer;
       }
     }
     /* FIXME policy stuff goes here */
     /* find connection with lowest timestamp */
     if (min == NULL || (connection->buffer != NULL &&
-	(GST_BUFFER_TIMESTAMP (connection->buffer) < 
-	 GST_BUFFER_TIMESTAMP (min->buffer)))) 
-    {
+            (GST_BUFFER_TIMESTAMP (connection->buffer) <
+                GST_BUFFER_TIMESTAMP (min->buffer)))) {
       min = connection;
     }
     connections = g_slist_next (connections);
@@ -327,20 +314,21 @@ gst_shaper_loop (GstElement *element)
     /* since we pushed a buffer, it's not EOS */
     eos = FALSE;
   }
-  
+
   if (eos) {
     gst_element_set_eos (element);
   }
 }
 
-static void 
-gst_shaper_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec) 
+static void
+gst_shaper_set_property (GObject * object, guint prop_id, const GValue * value,
+    GParamSpec * pspec)
 {
   GstShaper *shaper;
 
   /* it's not null if we got it, but it might not be ours */
   g_return_if_fail (GST_IS_SHAPER (object));
-  
+
   shaper = GST_SHAPER (object);
 
   switch (prop_id) {
@@ -356,12 +344,15 @@ gst_shaper_set_property (GObject *object, guint prop_id, const GValue *value, GP
   }
 }
 
-static void gst_shaper_get_property(GObject *object, guint prop_id, GValue *value, GParamSpec *pspec) {
+static void
+gst_shaper_get_property (GObject * object, guint prop_id, GValue * value,
+    GParamSpec * pspec)
+{
   GstShaper *shaper;
 
   /* it's not null if we got it, but it might not be ours */
   g_return_if_fail (GST_IS_SHAPER (object));
-  
+
   shaper = GST_SHAPER (object);
 
   switch (prop_id) {
@@ -379,12 +370,3 @@ static void gst_shaper_get_property(GObject *object, guint prop_id, GValue *valu
       break;
   }
 }
-
-gboolean
-gst_shaper_factory_init (GstElementFactory *factory)
-{
-  gst_element_factory_add_pad_template (factory, GST_PAD_TEMPLATE_GET (shaper_src_factory));
-  gst_element_factory_add_pad_template (factory, GST_PAD_TEMPLATE_GET (shaper_sink_factory));
-
-  return TRUE;
-}
