@@ -290,7 +290,8 @@ typedef struct
 
   GList *buffers;
   GstTypeFindElement *self;
-} TypeFindEntry;
+}
+TypeFindEntry;
 
 static inline TypeFindEntry *
 new_entry (void)
@@ -348,20 +349,20 @@ stop_typefinding (GstTypeFindElement * typefind)
     GstBuffer *buffer;
     guint size = gst_buffer_store_get_size (typefind->store, 0);
 
-    if (size
-        && (buffer = gst_buffer_store_get_buffer (typefind->store, 0, size))) {
-      GST_LOG_OBJECT (typefind, "pushing cached data (%u bytes)", size);
-      gst_pad_push (typefind->src, GST_DATA (buffer));
-    } else {
-      size = 0;
-    }
-    GST_LOG_OBJECT (typefind, "seeking back to current position %u", size);
+    GST_DEBUG_OBJECT (typefind, "seeking back to current position %u", size);
     if (!gst_pad_send_event (GST_PAD_PEER (typefind->sink),
             gst_event_new_seek (GST_SEEK_METHOD_SET | GST_FORMAT_BYTES,
                 size))) {
       GST_WARNING_OBJECT (typefind,
           "could not seek to required position %u, hope for the best", size);
     }
+    if (size
+        && (buffer = gst_buffer_store_get_buffer (typefind->store, 0, size))) {
+      GST_DEBUG_OBJECT (typefind, "pushing cached data (%u bytes)", size);
+      gst_pad_push (typefind->src, GST_DATA (buffer));
+    } else {
+      size = 0;
+    }
   }
   gst_buffer_store_clear (typefind->store);
 }
