@@ -48,8 +48,6 @@ static GstRegistry *_user_registry;
 static gboolean _gst_registry_fixed = FALSE;
 #endif
 
-static gboolean _gst_use_threads = TRUE;
-
 static gboolean _gst_enable_cpu_opt = TRUE;
 
 static gboolean gst_initialized = FALSE;
@@ -61,8 +59,6 @@ extern gint _gst_trace_on;
 /* set to TRUE when segfaults need to be left as is */
 gboolean _gst_disable_segtrap = FALSE;
 
-extern GThreadFunctions gst_thread_dummy_functions;
-
 
 static void load_plugin_func (gpointer data, gpointer user_data);
 static void init_popt_callback (poptContext context,
@@ -109,63 +105,6 @@ enum
 #define NUL '\0'
 #endif
 
-/* default scheduler, can be changed in gstscheduler.h with
- * the GST_SCHEDULER_DEFAULT_NAME define.
- */
-static const GstPoptOption gstreamer_options[] = {
-  {NULL, NUL, POPT_ARG_CALLBACK | POPT_CBFLAG_PRE | POPT_CBFLAG_POST,
-      (void *) &init_popt_callback, 0, NULL, NULL},
-  /* make sure we use our GETTEXT_PACKAGE as the domain for popt translations */
-  {NULL, NUL, POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL},
-  {"gst-version", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL, ARG_VERSION,
-      N_("Print the GStreamer version"), NULL},
-  {"gst-fatal-warnings", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
-      ARG_FATAL_WARNINGS, N_("Make all warnings fatal"), NULL},
-
-#ifndef GST_DISABLE_GST_DEBUG
-  {"gst-debug-help", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
-      ARG_DEBUG_HELP, N_("Print available debug categories and exit"), NULL},
-  {"gst-debug-level", NUL, POPT_ARG_INT | POPT_ARGFLAG_STRIP, NULL,
-        ARG_DEBUG_LEVEL,
-        N_
-        ("Default debug level from 1 (only error) to 5 (anything) or 0 for no output"),
-      N_("LEVEL")},
-  {"gst-debug", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL, ARG_DEBUG,
-        N_
-        ("Comma-separated list of category_name:level pairs to set specific levels for the individual categories. Example: GST_AUTOPLUG:5,GST_ELEMENT_*:3"),
-      N_("LIST")},
-  {"gst-debug-no-color", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
-      ARG_DEBUG_NO_COLOR, N_("Disable colored debugging output"), NULL},
-  {"gst-debug-disable", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
-      ARG_DEBUG_DISABLE, N_("Disable debugging")},
-#endif
-
-  {"gst-disable-cpu-opt", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
-      ARG_DISABLE_CPU_OPT, N_("Disable accelerated CPU instructions"), NULL},
-  {"gst-plugin-spew", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
-      ARG_PLUGIN_SPEW, N_("Enable verbose plugin loading diagnostics"), NULL},
-  {"gst-plugin-path", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
-        ARG_PLUGIN_PATH,
-      N_("path list for loading plugins (separated by '"
-            G_SEARCHPATH_SEPARATOR_S "')"), N_("PATHS")},
-  {"gst-plugin-load", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
-        ARG_PLUGIN_LOAD,
-        N_
-        ("Comma-separated list of plugins to preload in addition to the list stored in env variable GST_PLUGIN_PATH"),
-      N_("PLUGINS")},
-  {"gst-disable-segtrap", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
-        ARG_SEGTRAP_DISABLE,
-        N_("Disable trapping of segmentation faults during plugin loading"),
-      NULL},
-  {"gst-scheduler", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
-        ARG_SCHEDULER,
-      N_("Scheduler to use ('" GST_SCHEDULER_DEFAULT_NAME
-            "' is the default)"), N_("SCHEDULER")},
-  {"gst-registry", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
-      ARG_REGISTRY, N_("Registry to use"), N_("REGISTRY")},
-  POPT_TABLEEND
-};
-
 /**
  * gst_init_get_popt_table:
  *
@@ -183,6 +122,78 @@ static const GstPoptOption gstreamer_options[] = {
 const GstPoptOption *
 gst_init_get_popt_table (void)
 {
+  static GstPoptOption gstreamer_options[] = {
+    {NULL, NUL, POPT_ARG_CALLBACK | POPT_CBFLAG_PRE | POPT_CBFLAG_POST,
+        (void *) &init_popt_callback, 0, NULL, NULL},
+    /* make sure we use our GETTEXT_PACKAGE as the domain for popt translations */
+    {NULL, NUL, POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL},
+    {"gst-version", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL, ARG_VERSION,
+        N_("Print the GStreamer version"), NULL},
+    {"gst-fatal-warnings", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
+        ARG_FATAL_WARNINGS, N_("Make all warnings fatal"), NULL},
+
+#ifndef GST_DISABLE_GST_DEBUG
+    {"gst-debug-help", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
+        ARG_DEBUG_HELP, N_("Print available debug categories and exit"), NULL},
+    {"gst-debug-level", NUL, POPT_ARG_INT | POPT_ARGFLAG_STRIP, NULL,
+          ARG_DEBUG_LEVEL,
+          N_("Default debug level from 1 (only error) to 5 (anything) or "
+              "0 for no output"),
+        N_("LEVEL")},
+    {"gst-debug", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL, ARG_DEBUG,
+          N_("Comma-separated list of category_name:level pairs to set "
+              "specific levels for the individual categories. Example: "
+              "GST_AUTOPLUG:5,GST_ELEMENT_*:3"),
+        N_("LIST")},
+    {"gst-debug-no-color", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
+        ARG_DEBUG_NO_COLOR, N_("Disable colored debugging output"), NULL},
+    {"gst-debug-disable", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
+        ARG_DEBUG_DISABLE, N_("Disable debugging")},
+#endif
+
+    {"gst-disable-cpu-opt", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
+        ARG_DISABLE_CPU_OPT, N_("Disable accelerated CPU instructions"), NULL},
+    {"gst-plugin-spew", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
+        ARG_PLUGIN_SPEW, N_("Enable verbose plugin loading diagnostics"), NULL},
+    {"gst-plugin-path", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
+        ARG_PLUGIN_PATH, NULL, N_("PATHS")},
+    {"gst-plugin-load", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
+          ARG_PLUGIN_LOAD,
+          N_("Comma-separated list of plugins to preload in addition to the "
+              "list stored in envronment variable GST_PLUGIN_PATH"),
+        N_("PLUGINS")},
+    {"gst-disable-segtrap", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
+          ARG_SEGTRAP_DISABLE,
+          N_("Disable trapping of segmentation faults during plugin loading"),
+        NULL},
+    {"gst-scheduler", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
+        ARG_SCHEDULER, NULL, N_("SCHEDULER")},
+    {"gst-registry", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
+        ARG_REGISTRY, N_("Registry to use"), N_("REGISTRY")},
+    POPT_TABLEEND
+  };
+  static gboolean inited = FALSE;
+
+  if (!inited) {
+    int i;
+
+    for (i = 0; i < G_N_ELEMENTS (gstreamer_options); i++) {
+      if (gstreamer_options[i].longName == NULL) {
+      } else if (strcmp (gstreamer_options[i].longName, "gst-plugin-path") == 0) {
+        gstreamer_options[i].descrip =
+            g_strdup_printf (_
+            ("path list for loading plugins (separated by '%s')"),
+            G_SEARCHPATH_SEPARATOR_S);
+      } else if (strcmp (gstreamer_options[i].longName, "gst-scheduler") == 0) {
+        gstreamer_options[i].descrip =
+            g_strdup_printf (_("Scheduler to use (default is '%s')"),
+            GST_SCHEDULER_DEFAULT_NAME);
+      }
+    }
+
+    inited = TRUE;
+  }
+
   return gstreamer_options;
 }
 
@@ -217,6 +228,11 @@ gst_init_check (int *argc, char **argv[])
  * This function will terminate your program if it was unable to initialize
  * GStreamer for some reason.  If you want your program to fall back,
  * use gst_init_check() instead.
+ *
+ * WARNING: This function does not work in the same way as corresponding
+ * functions in other glib-style libraries, such as gtk_init().  In
+ * particular, unknown command line options cause this function to
+ * abort program execution.
  */
 void
 gst_init (int *argc, char **argv[])
@@ -270,7 +286,8 @@ gst_init_check_with_popt_table (int *argc, char **argv[],
   GstPoptOption options_with[] = {
     {NULL, NUL, POPT_ARG_INCLUDE_TABLE, poptHelpOptions, 0, "Help options:",
         NULL},
-    {NULL, NUL, POPT_ARG_INCLUDE_TABLE, (GstPoptOption *) gstreamer_options, 0,
+    {NULL, NUL, POPT_ARG_INCLUDE_TABLE,
+          (GstPoptOption *) gst_init_get_popt_table (), 0,
         "GStreamer options:", NULL},
     {NULL, NUL, POPT_ARG_INCLUDE_TABLE, (GstPoptOption *) popt_options, 0,
         "Application options:", NULL},
@@ -279,7 +296,8 @@ gst_init_check_with_popt_table (int *argc, char **argv[],
   GstPoptOption options_without[] = {
     {NULL, NUL, POPT_ARG_INCLUDE_TABLE, poptHelpOptions, 0, "Help options:",
         NULL},
-    {NULL, NUL, POPT_ARG_INCLUDE_TABLE, (GstPoptOption *) gstreamer_options, 0,
+    {NULL, NUL, POPT_ARG_INCLUDE_TABLE,
+          (GstPoptOption *) gst_init_get_popt_table (), 0,
         "GStreamer options:", NULL},
     POPT_TABLEEND
   };
@@ -432,12 +450,8 @@ init_pre (void)
 
   if (g_thread_supported ()) {
     /* somebody already initialized threading */
-    _gst_use_threads = TRUE;
   } else {
-    if (_gst_use_threads)
-      g_thread_init (NULL);
-    else
-      g_thread_init (&gst_thread_dummy_functions);
+    g_thread_init (NULL);
   }
   /* we need threading to be enabled right here */
   _gst_debug_init ();
@@ -549,8 +563,7 @@ init_post (void)
   llf = G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_ERROR | G_LOG_FLAG_FATAL;
   g_log_set_handler (g_log_domain_gstreamer, llf, debug_log_handler, NULL);
 
-  GST_INFO ("Initializing GStreamer Core Library version %s %s",
-      VERSION, _gst_use_threads ? "" : "(no threads)");
+  GST_INFO ("Initializing GStreamer Core Library version %s", VERSION);
 
   _gst_format_initialize ();
   _gst_query_type_initialize ();
@@ -789,27 +802,19 @@ init_popt_callback (poptContext context, enum poptCallbackReason reason,
  * gst_use_threads:
  * @use_threads: a #gboolean indicating whether threads should be used
  *
- * Instructs the core to turn on/off threading. When threading
- * is turned off, all thread operations such as mutexes and conditionals
- * are turned into NOPs. use this if you want absolute minimal overhead
- * and you don't use any threads in the pipeline.
- * <note><para>
- * This function may only be called before threads are initialized. This
- * usually happens when calling gst_init.
- * </para></note>
+ * This function is deprecated and should not be used in new code.
+ * GStreamer requires threads to be enabled at all times.
  */
 void
 gst_use_threads (gboolean use_threads)
 {
-  g_return_if_fail (!gst_initialized);
-  g_return_if_fail (g_thread_supported ());
-
-  _gst_use_threads = use_threads;
 }
 
 /**
  * gst_has_threads:
  *
+ * This function is deprecated and should not be used in new code.
+ *
  * Queries if GStreamer has threads enabled.
  *
  * Returns: %TRUE if threads are enabled.
@@ -817,7 +822,7 @@ gst_use_threads (gboolean use_threads)
 gboolean
 gst_has_threads (void)
 {
-  return _gst_use_threads;
+  return TRUE;
 }
 
 
@@ -827,6 +832,9 @@ static GSList *mainloops = NULL;
  * gst_main:
  *
  * Enters the main GStreamer processing loop.
+ *
+ * This function duplicates functionality in glib, and will be removed
+ * during the 0.9 development series.
  */
 void
 gst_main (void)
@@ -843,6 +851,9 @@ gst_main (void)
  * gst_main_quit:
  *
  * Exits the main GStreamer processing loop.
+ *
+ * This function duplicates functionality in glib, and will be removed
+ * during the 0.9 development series.
  */
 void
 gst_main_quit (void)
