@@ -39,19 +39,20 @@ static GstAllocTrace *_gst_buffer_trace;
 
 static GstMemChunk *chunk;
 
+static GstBuffer *gst_buffer_alloc_chunk (void);
+static void gst_buffer_free_chunk (GstBuffer * buffer);
+
 void
 _gst_buffer_initialize (void)
 {
-  _gst_buffer_type = g_boxed_type_register_static ("GstBuffer",
-		       (GBoxedCopyFunc) gst_data_ref,
-		       (GBoxedFreeFunc) gst_data_unref);
+  gst_buffer_get_type ();
 
 #ifndef GST_DISABLE_TRACE
   _gst_buffer_trace = gst_alloc_trace_register (GST_BUFFER_TRACE_NAME);
 #endif
 
-  chunk = gst_mem_chunk_new ("GstBufferChunk", sizeof (GstBuffer), 
-                             sizeof (GstBuffer) * 200, 0);
+  chunk = gst_mem_chunk_new ("GstBufferChunk", sizeof (GstBuffer),
+      sizeof (GstBuffer) * 200, 0);
 
   GST_CAT_LOG (GST_CAT_BUFFER, "Buffers are initialized now");
 }
@@ -59,11 +60,15 @@ _gst_buffer_initialize (void)
 GType
 gst_buffer_get_type (void)
 {
+  if (_gst_buffer_type == 0) {
+    _gst_buffer_type = g_boxed_type_register_static ("GstBuffer",
+        (GBoxedCopyFunc) gst_data_copy, (GBoxedFreeFunc) gst_data_unref);
+  }
   return _gst_buffer_type;
 }
 
 static void
-_gst_buffer_sub_free (GstBuffer *buffer)
+_gst_buffer_sub_free (GstBuffer * buffer)
 {
   gst_data_unref (GST_DATA (buffer->buffer_private));
 
@@ -71,11 +76,8 @@ _gst_buffer_sub_free (GstBuffer *buffer)
   GST_BUFFER_SIZE (buffer) = 0;
 
   _GST_DATA_DISPOSE (GST_DATA (buffer));
-  
-  gst_mem_chunk_free (chunk, GST_DATA (buffer));
-#ifndef GST_DISABLE_TRACE
-  gst_alloc_trace_free (_gst_buffer_trace, buffer);
-#endif
+
+  gst_buffer_free_chunk (buffer);
 }
 
 /**
@@ -86,14 +88,14 @@ _gst_buffer_sub_free (GstBuffer *buffer)
  * unless the GST_BUFFER_DONTFREE flags was set or the buffer data is NULL.
  */
 void
-gst_buffer_default_free (GstBuffer *buffer)
+gst_buffer_default_free (GstBuffer * buffer)
 {
   g_return_if_fail (buffer != NULL);
 
   /* free our data */
   if (GST_BUFFER_FREE_DATA_FUNC (buffer)) {
     GST_BUFFER_FREE_DATA_FUNC (buffer) (buffer);
-  } else if (!GST_BUFFER_FLAG_IS_SET (buffer, GST_BUFFER_DONTFREE)) { 
+  } else if (!GST_BUFFER_FLAG_IS_SET (buffer, GST_BUFFER_DONTFREE)) {
     g_free (GST_BUFFER_DATA (buffer));
   }
 
@@ -103,10 +105,7 @@ gst_buffer_default_free (GstBuffer *buffer)
 
   _GST_DATA_DISPOSE (GST_DATA (buffer));
 
-  gst_mem_chunk_free (chunk, GST_DATA (buffer));
-#ifndef GST_DISABLE_TRACE
-  gst_alloc_trace_free (_gst_buffer_trace, buffer);
-#endif
+  gst_buffer_free_chunk (buffer);
 }
 
 /**
@@ -118,16 +117,17 @@ gst_buffer_default_free (GstBuffer *buffer)
  * the other.
  */
 void
-gst_buffer_stamp (GstBuffer *dest, const GstBuffer *src)
+gst_buffer_stamp (GstBuffer * dest, const GstBuffer * src)
 {
   g_return_if_fail (dest != NULL);
   g_return_if_fail (src != NULL);
-  
-  GST_BUFFER_TIMESTAMP (dest) 	 = GST_BUFFER_TIMESTAMP (src);
-  GST_BUFFER_DURATION (dest) 	 = GST_BUFFER_DURATION (src);
-  GST_BUFFER_OFFSET (dest) 	 = GST_BUFFER_OFFSET (src);
-  GST_BUFFER_OFFSET_END (dest) 	 = GST_BUFFER_OFFSET_END (src);
+
+  GST_BUFFER_TIMESTAMP (dest) = GST_BUFFER_TIMESTAMP (src);
+  GST_BUFFER_DURATION (dest) = GST_BUFFER_DURATION (src);
+  GST_BUFFER_OFFSET (dest) = GST_BUFFER_OFFSET (src);
+  GST_BUFFER_OFFSET_END (dest) = GST_BUFFER_OFFSET_END (src);
 }
+
 /**
  * gst_buffer_default_copy:
  * @buffer: a #GstBuffer to make a copy of.
@@ -136,30 +136,27 @@ gst_buffer_stamp (GstBuffer *dest, const GstBuffer *src)
  *
  * Returns: the new #GstBuffer.
  */
-GstBuffer*
-gst_buffer_default_copy (GstBuffer *buffer)
+GstBuffer *
+gst_buffer_default_copy (GstBuffer * buffer)
 {
   GstBuffer *copy;
 
   g_return_val_if_fail (buffer != NULL, NULL);
 
   /* create a fresh new buffer */
-  copy = gst_mem_chunk_alloc (chunk);
-#ifndef GST_DISABLE_TRACE
-  gst_alloc_trace_new (_gst_buffer_trace, copy);
-#endif
+  copy = gst_buffer_alloc_chunk ();
 
-  _GST_DATA_INIT (GST_DATA (copy), 
-		  _gst_buffer_type,
-		  0,
-		  (GstDataFreeFunction) gst_buffer_default_free,
-		  (GstDataCopyFunction) gst_buffer_default_copy);
+  _GST_DATA_INIT (GST_DATA (copy),
+      _gst_buffer_type,
+      0,
+      (GstDataFreeFunction) gst_buffer_default_free,
+      (GstDataCopyFunction) gst_buffer_default_copy);
 
   /* we simply copy everything from our parent */
-  GST_BUFFER_DATA (copy) 	 = g_memdup (GST_BUFFER_DATA (buffer), 
-                                             GST_BUFFER_SIZE (buffer));
-  GST_BUFFER_SIZE (copy)  	 = GST_BUFFER_SIZE (buffer);
-  GST_BUFFER_MAXSIZE (copy) 	 = GST_BUFFER_SIZE (buffer);
+  GST_BUFFER_DATA (copy) = g_memdup (GST_BUFFER_DATA (buffer),
+      GST_BUFFER_SIZE (buffer));
+  GST_BUFFER_SIZE (copy) = GST_BUFFER_SIZE (buffer);
+  GST_BUFFER_MAXSIZE (copy) = GST_BUFFER_SIZE (buffer);
 
   gst_buffer_stamp (copy, buffer);
   GST_BUFFER_FREE_DATA_FUNC (copy) = NULL;
@@ -168,6 +165,28 @@ gst_buffer_default_copy (GstBuffer *buffer)
   return copy;
 }
 
+static GstBuffer *
+gst_buffer_alloc_chunk (void)
+{
+  GstBuffer *newbuf;
+
+  newbuf = gst_mem_chunk_alloc (chunk);
+#ifndef GST_DISABLE_TRACE
+  gst_alloc_trace_new (_gst_buffer_trace, newbuf);
+#endif
+
+  return newbuf;
+}
+
+static void
+gst_buffer_free_chunk (GstBuffer * buffer)
+{
+  gst_mem_chunk_free (chunk, GST_DATA (buffer));
+#ifndef GST_DISABLE_TRACE
+  gst_alloc_trace_free (_gst_buffer_trace, buffer);
+#endif
+}
+
 /**
  * gst_buffer_new:
  *
@@ -175,31 +194,28 @@ gst_buffer_default_copy (GstBuffer *buffer)
  *
  * Returns: the new #GstBuffer.
  */
-GstBuffer*
+GstBuffer *
 gst_buffer_new (void)
 {
   GstBuffer *newbuf;
-  
-  newbuf = gst_mem_chunk_alloc (chunk);
-#ifndef GST_DISABLE_TRACE
-  gst_alloc_trace_new (_gst_buffer_trace, newbuf);
-#endif
+
+  newbuf = gst_buffer_alloc_chunk ();
 
   GST_CAT_LOG (GST_CAT_BUFFER, "new %p", newbuf);
 
-  _GST_DATA_INIT (GST_DATA (newbuf), 
-		  _gst_buffer_type,
-		  0,
-		  (GstDataFreeFunction) gst_buffer_default_free,
-		  (GstDataCopyFunction) gst_buffer_default_copy);
+  _GST_DATA_INIT (GST_DATA (newbuf),
+      _gst_buffer_type,
+      0,
+      (GstDataFreeFunction) gst_buffer_default_free,
+      (GstDataCopyFunction) gst_buffer_default_copy);
 
-  GST_BUFFER_DATA (newbuf)         = NULL;
-  GST_BUFFER_SIZE (newbuf)         = 0;
-  GST_BUFFER_MAXSIZE (newbuf)      = GST_BUFFER_MAXSIZE_NONE;
-  GST_BUFFER_TIMESTAMP (newbuf)    = GST_CLOCK_TIME_NONE;
-  GST_BUFFER_DURATION (newbuf)     = GST_CLOCK_TIME_NONE;
-  GST_BUFFER_OFFSET (newbuf)       = GST_BUFFER_OFFSET_NONE;
-  GST_BUFFER_OFFSET_END (newbuf)   = GST_BUFFER_OFFSET_NONE;
+  GST_BUFFER_DATA (newbuf) = NULL;
+  GST_BUFFER_SIZE (newbuf) = 0;
+  GST_BUFFER_MAXSIZE (newbuf) = GST_BUFFER_MAXSIZE_NONE;
+  GST_BUFFER_TIMESTAMP (newbuf) = GST_CLOCK_TIME_NONE;
+  GST_BUFFER_DURATION (newbuf) = GST_CLOCK_TIME_NONE;
+  GST_BUFFER_OFFSET (newbuf) = GST_BUFFER_OFFSET_NONE;
+  GST_BUFFER_OFFSET_END (newbuf) = GST_BUFFER_OFFSET_NONE;
   GST_BUFFER_FREE_DATA_FUNC (newbuf) = NULL;
   GST_BUFFER_PRIVATE (newbuf) = NULL;
 
@@ -214,15 +230,15 @@ gst_buffer_new (void)
  *
  * Returns: the new #GstBuffer.
  */
-GstBuffer*
+GstBuffer *
 gst_buffer_new_and_alloc (guint size)
 {
   GstBuffer *newbuf;
 
   newbuf = gst_buffer_new ();
 
-  GST_BUFFER_DATA (newbuf)    = g_malloc (size);
-  GST_BUFFER_SIZE (newbuf)    = size;
+  GST_BUFFER_DATA (newbuf) = g_malloc (size);
+  GST_BUFFER_SIZE (newbuf) = size;
   GST_BUFFER_MAXSIZE (newbuf) = size;
 
   return newbuf;
@@ -242,12 +258,12 @@ gst_buffer_new_and_alloc (guint size)
  *
  * Returns: the new #GstBuffer, or NULL if there was an error.
  */
-GstBuffer*
-gst_buffer_create_sub (GstBuffer *parent, guint offset, guint size)
+GstBuffer *
+gst_buffer_create_sub (GstBuffer * parent, guint offset, guint size)
 {
   GstBuffer *buffer;
   gpointer buffer_data;
-	      
+
   g_return_val_if_fail (parent != NULL, NULL);
   g_return_val_if_fail (GST_BUFFER_REFCOUNT_VALUE (parent) > 0, NULL);
   g_return_val_if_fail (size > 0, NULL);
@@ -263,41 +279,37 @@ gst_buffer_create_sub (GstBuffer *parent, guint offset, guint size)
   gst_data_ref (GST_DATA (parent));
 
   /* create the new buffer */
-  buffer = gst_mem_chunk_alloc (chunk);
-#ifndef GST_DISABLE_TRACE
-  gst_alloc_trace_new (_gst_buffer_trace, buffer);
-#endif
+  buffer = gst_buffer_alloc_chunk ();
 
   GST_CAT_LOG (GST_CAT_BUFFER, "new subbuffer %p (parent %p)", buffer, parent);
 
   /* make sure nobody overwrites data in the new buffer 
    * by setting the READONLY flag */
-  _GST_DATA_INIT (GST_DATA (buffer), 
-		  _gst_buffer_type,
-		  GST_DATA_FLAG_SHIFT (GST_BUFFER_SUBBUFFER) |
-		  GST_DATA_FLAG_SHIFT (GST_DATA_READONLY),
-		  (GstDataFreeFunction) _gst_buffer_sub_free,
-		  (GstDataCopyFunction) gst_buffer_default_copy);
+  _GST_DATA_INIT (GST_DATA (buffer),
+      _gst_buffer_type,
+      GST_DATA_FLAG_SHIFT (GST_BUFFER_SUBBUFFER) |
+      GST_DATA_FLAG_SHIFT (GST_DATA_READONLY),
+      (GstDataFreeFunction) _gst_buffer_sub_free,
+      (GstDataCopyFunction) gst_buffer_default_copy);
 
   /* set the right values in the child */
-  GST_BUFFER_DATA (buffer)         = buffer_data;
-  GST_BUFFER_SIZE (buffer)         = size;
-  GST_BUFFER_MAXSIZE (buffer)      = size;
+  GST_BUFFER_DATA (buffer) = buffer_data;
+  GST_BUFFER_SIZE (buffer) = size;
+  GST_BUFFER_MAXSIZE (buffer) = size;
   GST_BUFFER_FREE_DATA_FUNC (buffer) = NULL;
   GST_BUFFER_PRIVATE (buffer) = parent;
   /* we can copy the timestamp and offset if the new buffer starts at
    * offset 0 */
   if (offset == 0) {
-    GST_BUFFER_TIMESTAMP (buffer)    = GST_BUFFER_TIMESTAMP (parent);
-    GST_BUFFER_OFFSET (buffer)       = GST_BUFFER_OFFSET (parent);
-  }
-  else {
-    GST_BUFFER_TIMESTAMP (buffer)    = GST_CLOCK_TIME_NONE;
-    GST_BUFFER_OFFSET (buffer)       = GST_BUFFER_OFFSET_NONE;
+    GST_BUFFER_TIMESTAMP (buffer) = GST_BUFFER_TIMESTAMP (parent);
+    GST_BUFFER_OFFSET (buffer) = GST_BUFFER_OFFSET (parent);
+  } else {
+    GST_BUFFER_TIMESTAMP (buffer) = GST_CLOCK_TIME_NONE;
+    GST_BUFFER_OFFSET (buffer) = GST_BUFFER_OFFSET_NONE;
   }
 
-  GST_BUFFER_DURATION (buffer)     = GST_CLOCK_TIME_NONE;
-  GST_BUFFER_OFFSET_END (buffer)   = GST_BUFFER_OFFSET_NONE;
+  GST_BUFFER_DURATION (buffer) = GST_CLOCK_TIME_NONE;
+  GST_BUFFER_OFFSET_END (buffer) = GST_BUFFER_OFFSET_NONE;
 
   if (GST_BUFFER_FLAG_IS_SET (parent, GST_BUFFER_DONTKEEP)) {
     GST_BUFFER_FLAG_SET (buffer, GST_BUFFER_DONTKEEP);
@@ -319,13 +331,16 @@ gst_buffer_create_sub (GstBuffer *parent, guint offset, guint size)
  * buffers.  The original source buffers will not be modified or
  * unref'd.
  *
- * Internally is nothing more than a specialized gst_buffer_span(),
- * so the same optimizations can occur.
+ * WARNING: Incorrect use of this function can lead to memory leaks.
+ * It is recommended to use gst_buffer_join() instead of this function.
+ *
+ * If the buffers point to contiguous areas of memory, the buffer
+ * is created without copying the data.
  *
  * Returns: the new #GstBuffer that's the concatenation of the source buffers.
  */
-GstBuffer*
-gst_buffer_merge (GstBuffer *buf1, GstBuffer *buf2)
+GstBuffer *
+gst_buffer_merge (GstBuffer * buf1, GstBuffer * buf2)
 {
   GstBuffer *result;
 
@@ -335,19 +350,46 @@ gst_buffer_merge (GstBuffer *buf1, GstBuffer *buf2)
   return result;
 }
 
+/**
+ * gst_buffer_join:
+ * @buf1: a first source #GstBuffer to merge.
+ * @buf2: the second source #GstBuffer to merge.
+ *
+ * Create a new buffer that is the concatenation of the two source
+ * buffers.  The original buffers are unreferenced.
+ *
+ * If the buffers point to contiguous areas of memory, the buffer
+ * is created without copying the data.
+ *
+ * Returns: the new #GstBuffer that's the concatenation of the source buffers.
+ */
+GstBuffer *
+gst_buffer_join (GstBuffer * buf1, GstBuffer * buf2)
+{
+  GstBuffer *result;
+
+  /* we're just a specific case of the more general gst_buffer_span() */
+  result = gst_buffer_span (buf1, 0, buf2, buf1->size + buf2->size);
+
+  gst_buffer_unref (buf1);
+  gst_buffer_unref (buf2);
+
+  return result;
+}
+
 /**
  * gst_buffer_is_span_fast:
  * @buf1: a first source #GstBuffer.
  * @buf2: the second source #GstBuffer.
  *
- * Determines whether a gst_buffer_span() is free (as in free beer), 
- * or requires a memcpy. 
+ * Determines whether a gst_buffer_span() can be done without copying
+ * the contents, that is, whether the data areas are contiguous.
  *
  * Returns: TRUE if the buffers are contiguous, 
  * FALSE if a copy would be required.
  */
 gboolean
-gst_buffer_is_span_fast (GstBuffer *buf1, GstBuffer *buf2)
+gst_buffer_is_span_fast (GstBuffer * buf1, GstBuffer * buf2)
 {
   g_return_val_if_fail (buf1 != NULL && buf2 != NULL, FALSE);
   g_return_val_if_fail (GST_BUFFER_REFCOUNT_VALUE (buf1) > 0, FALSE);
@@ -355,9 +397,9 @@ gst_buffer_is_span_fast (GstBuffer *buf1, GstBuffer *buf2)
 
   /* it's only fast if we have subbuffers of the same parent */
   return ((GST_BUFFER_FLAG_IS_SET (buf1, GST_BUFFER_SUBBUFFER)) &&
-          (GST_BUFFER_FLAG_IS_SET (buf2, GST_BUFFER_SUBBUFFER)) &&
- 	  (buf1->buffer_private == buf2->buffer_private) &&
-          ((buf1->data + buf1->size) == buf2->data));
+      (GST_BUFFER_FLAG_IS_SET (buf2, GST_BUFFER_SUBBUFFER)) &&
+      (buf1->buffer_private == buf2->buffer_private) &&
+      ((buf1->data + buf1->size) == buf2->data));
 }
 
 /**
@@ -380,8 +422,9 @@ gst_buffer_is_span_fast (GstBuffer *buf1, GstBuffer *buf2)
  *
  * Returns: the new #GstBuffer that spans the two source buffers.
  */
-GstBuffer*
-gst_buffer_span (GstBuffer *buf1, guint32 offset, GstBuffer *buf2, guint32 len)
+GstBuffer *
+gst_buffer_span (GstBuffer * buf1, guint32 offset, GstBuffer * buf2,
+    guint32 len)
 {
   GstBuffer *newbuf;
 
@@ -394,21 +437,21 @@ gst_buffer_span (GstBuffer *buf1, guint32 offset, GstBuffer *buf2, guint32 len)
   /* if the two buffers have the same parent and are adjacent */
   if (gst_buffer_is_span_fast (buf1, buf2)) {
     GstBuffer *parent = GST_BUFFER (buf1->buffer_private);
+
     /* we simply create a subbuffer of the common parent */
-    newbuf = gst_buffer_create_sub (parent, 
-	                            buf1->data - parent->data + offset, len);
-  }
-  else {
-    GST_CAT_DEBUG (GST_CAT_BUFFER, "slow path taken while spanning buffers %p and %p", 
-	       buf1, buf2);
+    newbuf = gst_buffer_create_sub (parent,
+        buf1->data - parent->data + offset, len);
+  } else {
+    GST_CAT_DEBUG (GST_CAT_BUFFER,
+        "slow path taken while spanning buffers %p and %p", buf1, buf2);
     /* otherwise we simply have to brute-force copy the buffers */
     newbuf = gst_buffer_new_and_alloc (len);
 
     /* copy the first buffer's data across */
     memcpy (newbuf->data, buf1->data + offset, buf1->size - offset);
     /* copy the second buffer's data across */
-    memcpy (newbuf->data + (buf1->size - offset), buf2->data, 
-	    len - (buf1->size - offset));
+    memcpy (newbuf->data + (buf1->size - offset), buf2->data,
+        len - (buf1->size - offset));
     /* if the offset is 0, the new buffer has the same timestamp as buf1 */
     if (offset == 0) {
       GST_BUFFER_OFFSET (newbuf) = GST_BUFFER_OFFSET (buf1);
@@ -420,10 +463,10 @@ gst_buffer_span (GstBuffer *buf1, guint32 offset, GstBuffer *buf2, guint32 len)
    * invalid DURATIONS */
   if (offset == 0 && buf1->size + buf2->size == len) {
     if (GST_BUFFER_DURATION_IS_VALID (buf1) &&
-	GST_BUFFER_DURATION_IS_VALID (buf2)) {
+        GST_BUFFER_DURATION_IS_VALID (buf2)) {
       /* add duration */
-      GST_BUFFER_DURATION (newbuf) = GST_BUFFER_DURATION (buf1) + 
-				    GST_BUFFER_DURATION (buf2);
+      GST_BUFFER_DURATION (newbuf) = GST_BUFFER_DURATION (buf1) +
+          GST_BUFFER_DURATION (buf2);
     }
     if (GST_BUFFER_OFFSET_END_IS_VALID (buf2)) {
       /* add offset_end */
@@ -433,4 +476,3 @@ gst_buffer_span (GstBuffer *buf1, guint32 offset, GstBuffer *buf2, guint32 len)
 
   return newbuf;
 }
-
