@@ -37,7 +37,7 @@ typedef void (*GstBufferFreeDataFunc) (GstBuffer *buffer);
 
 extern GType _gst_buffer_type;
 
-#define GST_TYPE_BUFFER         		(_gst_buffer_type)
+#define GST_TYPE_BUFFER         		(gst_buffer_get_type())
 
 #define GST_BUFFER(buf)         		((GstBuffer *)(buf))
 #define GST_IS_BUFFER(buf)      		(GST_DATA_TYPE(buf) == GST_TYPE_BUFFER)
@@ -59,7 +59,6 @@ extern GType _gst_buffer_type;
 #define GST_BUFFER_MAXSIZE(buf)			(GST_BUFFER(buf)->maxsize)
 #define GST_BUFFER_TIMESTAMP(buf)		(GST_BUFFER(buf)->timestamp)
 #define GST_BUFFER_DURATION(buf)		(GST_BUFFER(buf)->duration)
-#define GST_BUFFER_FORMAT(buf)			(GST_BUFFER(buf)->format)
 #define GST_BUFFER_OFFSET(buf)			(GST_BUFFER(buf)->offset)
 #define GST_BUFFER_OFFSET_END(buf)		(GST_BUFFER(buf)->offset_end)
 #define GST_BUFFER_FREE_DATA_FUNC(buf)          (GST_BUFFER(buf)->free_data)
@@ -138,6 +137,7 @@ GstBuffer*	gst_buffer_create_sub		(GstBuffer *parent, guint offset, guint size);
 
 /* merge, span, or append two buffers, intelligently */
 GstBuffer*	gst_buffer_merge		(GstBuffer *buf1, GstBuffer *buf2);
+GstBuffer*	gst_buffer_join 		(GstBuffer *buf1, GstBuffer *buf2);
 gboolean	gst_buffer_is_span_fast		(GstBuffer *buf1, GstBuffer *buf2);
 GstBuffer*	gst_buffer_span			(GstBuffer *buf1, guint32 offset, GstBuffer *buf2, guint32 len);
 
