@@ -144,6 +144,7 @@ typedef enum {
 #define GST_ELEMENT_ERROR(el, domain, code, message, debug) G_STMT_START { \
   gchar *__msg = _gst_element_error_printf message; \
   gchar *__dbg = _gst_element_error_printf debug; \
+  GST_ERROR_OBJECT (el, "%s", __msg); \
   GST_ERROR_OBJECT (el, "%s", __dbg); \
   gst_element_error_full (GST_ELEMENT(el), \
   GST_ ## domain ## _ERROR, GST_ ## domain ## _ERROR_ ## code, \
@@ -292,6 +293,8 @@ GstClockReturn		gst_element_clock_wait 		(GstElement *element,
 GstClockTime		gst_element_get_time		(GstElement *element);
 gboolean		gst_element_wait		(GstElement *element, GstClockTime timestamp);
 void			gst_element_set_time		(GstElement *element, GstClockTime time);
+void			gst_element_set_time_delay	(GstElement *element, GstClockTime time, GstClockTime delay);
+
 void			gst_element_adjust_time		(GstElement *element, GstClockTimeDiff diff);
  
 /* indexs */
@@ -430,7 +433,7 @@ struct _GstElementFactoryClass {
 GType 			gst_element_factory_get_type 		(void);
 
 gboolean		gst_element_register			(GstPlugin *plugin,
-								 const gchar *elementname,
+								 const gchar *name,
 								 guint rank,
 								 GType type);
 
