@@ -23,6 +23,10 @@
 #ifndef __GST_LOG_H__
 #define __GST_LOG_H__
 
+#include <glib.h>
+
+G_BEGIN_DECLS
+
 extern const char             *g_log_domain_gstreamer;
 
 #ifdef G_HAVE_ISO_VARARGS
@@ -46,4 +50,6 @@ extern const char             *g_log_domain_gstreamer;
 #endif
 #endif
 
+G_END_DECLS
+
 #endif /* __GST_LOG_H__ */
