@@ -33,40 +33,42 @@ GST_DEBUG_CATEGORY_STATIC (gst_tag_interface_debug);
 
 static GQuark gst_tag_key;
 
-typedef struct {
-  GstTagMergeMode	mode;
-  GstTagList *		list;
+typedef struct
+{
+  GstTagMergeMode mode;
+  GstTagList *list;
 } GstTagData;
 
 GType
 gst_tag_setter_get_type (void)
 {
   static GType tag_setter_type = 0;
-    
-  if (! tag_setter_type) {
+
+  if (!tag_setter_type) {
     static const GTypeInfo tag_setter_info = {
-      sizeof (GstTagSetterIFace), /* class_size */
-      NULL,		/* base_init */
-      NULL,             /* base_finalize */
+      sizeof (GstTagSetterIFace),       /* class_size */
+      NULL,                     /* base_init */
+      NULL,                     /* base_finalize */
       NULL,
-      NULL,             /* class_finalize */
-      NULL,             /* class_data */
+      NULL,                     /* class_finalize */
+      NULL,                     /* class_data */
       0,
       0,
       NULL
     };
-    
-    GST_DEBUG_CATEGORY_INIT (gst_tag_interface_debug, "GstTagInterface", 0, "interfaces for tagging");
-    
+
+    GST_DEBUG_CATEGORY_INIT (gst_tag_interface_debug, "GstTagInterface", 0,
+        "interfaces for tagging");
+
     tag_setter_type = g_type_register_static (G_TYPE_INTERFACE, "GstTagSetter",
-		                              &tag_setter_info, 0);
-    
+        &tag_setter_info, 0);
+
     g_type_interface_add_prerequisite (tag_setter_type, GST_TYPE_ELEMENT);
 
     gst_tag_key = g_quark_from_static_string ("GST_TAG_SETTER");
   }
-  
-  return tag_setter_type;	
+
+  return tag_setter_type;
 }
 static void
 gst_tag_data_free (gpointer p)
@@ -79,7 +81,7 @@ gst_tag_data_free (gpointer p)
   g_free (data);
 }
 static GstTagData *
-gst_tag_setter_get_data (GstTagSetter *setter)
+gst_tag_setter_get_data (GstTagSetter * setter)
 {
   GstTagData *data;
 
@@ -88,11 +90,13 @@ gst_tag_setter_get_data (GstTagSetter *setter)
     data = g_new (GstTagData, 1);
     data->list = NULL;
     data->mode = GST_TAG_MERGE_KEEP;
-    g_object_set_qdata_full (G_OBJECT (setter), gst_tag_key, data, gst_tag_data_free);
+    g_object_set_qdata_full (G_OBJECT (setter), gst_tag_key, data,
+        gst_tag_data_free);
   }
-  
+
   return data;
 }
+
 /**
  * gst_tag_setter_merge:
  * @setter: a #GstTagSetter
@@ -102,7 +106,8 @@ gst_tag_setter_get_data (GstTagSetter *setter)
  * Merges the given list into the setter's list using the given mode.
  */
 void
-gst_tag_setter_merge (GstTagSetter *setter, const GstTagList *list, GstTagMergeMode mode)
+gst_tag_setter_merge (GstTagSetter * setter, const GstTagList * list,
+    GstTagMergeMode mode)
 {
   GstTagData *data;
 
@@ -116,6 +121,7 @@ gst_tag_setter_merge (GstTagSetter *setter, const GstTagList *list, GstTagMergeM
     gst_tag_list_merge (data->list, list, mode);
   }
 }
+
 /**
  * gst_tag_setter_add:
  * @setter: a #GstTagSetter
@@ -127,7 +133,8 @@ gst_tag_setter_merge (GstTagSetter *setter, const GstTagList *list, GstTagMergeM
  * The list must be terminated with GST_TAG_INVALID.
  */
 void
-gst_tag_setter_add (GstTagSetter *setter, GstTagMergeMode mode, const gchar *tag, ...)
+gst_tag_setter_add (GstTagSetter * setter, GstTagMergeMode mode,
+    const gchar * tag, ...)
 {
   va_list args;
 
@@ -138,6 +145,7 @@ gst_tag_setter_add (GstTagSetter *setter, GstTagMergeMode mode, const gchar *tag
   gst_tag_setter_add_valist (setter, mode, tag, args);
   va_end (args);
 }
+
 /**
  * gst_tag_setter_add_values:
  * @setter: a #GstTagSetter
@@ -149,7 +157,8 @@ gst_tag_setter_add (GstTagSetter *setter, GstTagMergeMode mode, const gchar *tag
  * The list must be terminated with GST_TAG_INVALID.
  */
 void
-gst_tag_setter_add_values (GstTagSetter *setter, GstTagMergeMode mode, const gchar *tag, ...)
+gst_tag_setter_add_values (GstTagSetter * setter, GstTagMergeMode mode,
+    const gchar * tag, ...)
 {
   va_list args;
 
@@ -160,6 +169,7 @@ gst_tag_setter_add_values (GstTagSetter *setter, GstTagMergeMode mode, const gch
   gst_tag_setter_add_valist_values (setter, mode, tag, args);
   va_end (args);
 }
+
 /**
  * gst_tag_setter_add_valist:
  * @setter: a #GstTagSetter
@@ -171,19 +181,21 @@ gst_tag_setter_add_values (GstTagSetter *setter, GstTagMergeMode mode, const gch
  * The list must be terminated with GST_TAG_INVALID.
  */
 void
-gst_tag_setter_add_valist (GstTagSetter *setter, GstTagMergeMode mode, const gchar *tag, va_list var_args)
+gst_tag_setter_add_valist (GstTagSetter * setter, GstTagMergeMode mode,
+    const gchar * tag, va_list var_args)
 {
   GstTagData *data;
-  
+
   g_return_if_fail (GST_IS_TAG_SETTER (setter));
   g_return_if_fail (GST_TAG_MODE_IS_VALID (mode));
 
   data = gst_tag_setter_get_data (setter);
   if (!data->list)
     data->list = gst_tag_list_new ();
-  
+
   gst_tag_list_add_valist (data->list, mode, tag, var_args);
 }
+
 /**
  * gst_tag_setter_add_valist_values:
  * @setter: a #GstTagSetter
@@ -195,19 +207,21 @@ gst_tag_setter_add_valist (GstTagSetter *setter, GstTagMergeMode mode, const gch
  * The list must be terminated with GST_TAG_INVALID.
  */
 void
-gst_tag_setter_add_valist_values (GstTagSetter *setter, GstTagMergeMode mode, const gchar *tag, va_list var_args)
+gst_tag_setter_add_valist_values (GstTagSetter * setter, GstTagMergeMode mode,
+    const gchar * tag, va_list var_args)
 {
   GstTagData *data;
-  
+
   g_return_if_fail (GST_IS_TAG_SETTER (setter));
   g_return_if_fail (GST_TAG_MODE_IS_VALID (mode));
 
   data = gst_tag_setter_get_data (setter);
   if (!data->list)
     data->list = gst_tag_list_new ();
-  
+
   gst_tag_list_add_valist_values (data->list, mode, tag, var_args);
 }
+
 /**
  * gst_tag_setter_get_list:
  * @setter: a #GstTagSetter
@@ -218,13 +232,14 @@ gst_tag_setter_add_valist_values (GstTagSetter *setter, GstTagMergeMode mode, co
  * Returns: a current snapshot of the taglist used in the setter
  *	    or NULL if none is used.
  */
-const GstTagList *    
-gst_tag_setter_get_list (GstTagSetter *setter)
+const GstTagList *
+gst_tag_setter_get_list (GstTagSetter * setter)
 {
   g_return_val_if_fail (GST_IS_TAG_SETTER (setter), NULL);
 
   return gst_tag_setter_get_data (setter)->list;
 }
+
 /**
  * gst_tag_setter_set_merge_mode:
  * @setter: a #GstTagSetter
@@ -235,13 +250,14 @@ gst_tag_setter_get_list (GstTagSetter *setter)
  * the tags by this interface and discards tags from events.
  */
 void
-gst_tag_setter_set_merge_mode (GstTagSetter *setter, GstTagMergeMode mode)
+gst_tag_setter_set_merge_mode (GstTagSetter * setter, GstTagMergeMode mode)
 {
   g_return_if_fail (GST_IS_TAG_SETTER (setter));
   g_return_if_fail (GST_TAG_MODE_IS_VALID (mode));
 
   gst_tag_setter_get_data (setter)->mode = mode;
 }
+
 /**
  * gst_tag_setter_get_merge_mode:
  * @setter: a #GstTagSetter
@@ -252,7 +268,7 @@ gst_tag_setter_set_merge_mode (GstTagSetter *setter, GstTagMergeMode mode)
  * Returns: the merge mode used inside the element.
  */
 GstTagMergeMode
-gst_tag_setter_get_merge_mode (GstTagSetter *setter)
+gst_tag_setter_get_merge_mode (GstTagSetter * setter)
 {
   g_return_val_if_fail (GST_IS_TAG_SETTER (setter), FALSE);
 
