@@ -22,6 +22,7 @@
 #endif
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 
 #include <gst/gst.h>
 #include <gobject/gvaluecollector.h>
@@ -140,6 +141,10 @@ gst_value_lcopy_list (const GValue * value, guint n_collect_values,
 
 /**
  * gst_value_list_prepend_value:
+ * @value: a GstValueList to prepend a value to
+ * @prepend_value: the value to prepend
+ *
+ * Prepends @prepend_value to the GstValueList in @value.
  *
  */
 void
@@ -152,7 +157,10 @@ gst_value_list_prepend_value (GValue * value, const GValue * prepend_value)
 
 /**
  * gst_value_list_append_value:
+ * @value: a GstValueList to append a value to
+ * @append_value: the value to append
  *
+ * Appends @append_value to the GstValueList in @value.
  */
 void
 gst_value_list_append_value (GValue * value, const GValue * append_value)
@@ -164,7 +172,11 @@ gst_value_list_append_value (GValue * value, const GValue * append_value)
 
 /**
  * gst_value_list_get_size:
+ * @value: a GstValueList
  *
+ * Gets the number of values contained in @value.
+ *
+ * Returns: the number of values
  */
 guint
 gst_value_list_get_size (const GValue * value)
@@ -176,7 +188,13 @@ gst_value_list_get_size (const GValue * value)
 
 /**
  * gst_value_list_get_value:
+ * @value: a GstValueList
+ * @index: index of value to get from the list
  *
+ * Gets the value that is a member of the list contained in @value and
+ * has the index @index.
+ *
+ * Returns: the value at the given index
  */
 const GValue *
 gst_value_list_get_value (const GValue * value, guint index)
@@ -194,8 +212,8 @@ gst_value_list_get_value (const GValue * value, guint index)
  * @value1: first value to put into the union
  * @value2: second value to put into the union
  *
- * Concatenates copies of value1 and value2 into a list. dest will be 
- * initialized to the type GST_TYPE_LIST.
+ * Concatenates copies of value1 and value2 into a list.  The value
+ * @dest is initialized to the type GST_TYPE_LIST.
  */
 void
 gst_value_list_concat (GValue * dest, const GValue * value1,
@@ -362,7 +380,10 @@ gst_value_lcopy_fourcc (const GValue * value, guint n_collect_values,
 
 /**
  * gst_value_set_fourcc:
+ * @value: a GValue initialized to GST_TYPE_FOURCC
+ * @fourcc: the fourcc to set
  *
+ * Sets @value to @fourcc.
  */
 void
 gst_value_set_fourcc (GValue * value, guint32 fourcc)
@@ -374,7 +395,11 @@ gst_value_set_fourcc (GValue * value, guint32 fourcc)
 
 /**
  * gst_value_get_fourcc:
+ * @value: a GValue initialized to GST_TYPE_FOURCC
  *
+ * Gets the fourcc contained in @value.
+ *
+ * Returns: the fourcc contained in @value.
  */
 guint32
 gst_value_get_fourcc (const GValue * value)
@@ -495,7 +520,11 @@ gst_value_lcopy_int_range (const GValue * value, guint n_collect_values,
 
 /**
  * gst_value_set_int_range:
+ * @value: a GValue initialized to GST_TYPE_INT_RANGE
+ * @start: the start of the range
+ * @end: the end of the range
  *
+ * Sets @value to the range specified by @start and @end.
  */
 void
 gst_value_set_int_range (GValue * value, int start, int end)
@@ -508,7 +537,11 @@ gst_value_set_int_range (GValue * value, int start, int end)
 
 /**
  * gst_value_get_int_range_min:
+ * @value: a GValue initialized to GST_TYPE_INT_RANGE
  *
+ * Gets the minimum of the range specified by @value.
+ *
+ * Returns: the minumum of the range
  */
 int
 gst_value_get_int_range_min (const GValue * value)
@@ -520,7 +553,11 @@ gst_value_get_int_range_min (const GValue * value)
 
 /**
  * gst_value_get_int_range_max:
+ * @value: a GValue initialized to GST_TYPE_INT_RANGE
  *
+ * Gets the maximum of the range specified by @value.
+ *
+ * Returns: the maxumum of the range
  */
 int
 gst_value_get_int_range_max (const GValue * value)
@@ -610,7 +647,11 @@ gst_value_lcopy_double_range (const GValue * value, guint n_collect_values,
 
 /**
  * gst_value_set_double_range:
+ * @value: a GValue initialized to GST_TYPE_DOUBLE_RANGE
+ * @start: the start of the range
+ * @end: the end of the range
  *
+ * Sets @value to the range specified by @start and @end.
  */
 void
 gst_value_set_double_range (GValue * value, double start, double end)
@@ -623,7 +664,11 @@ gst_value_set_double_range (GValue * value, double start, double end)
 
 /**
  * gst_value_get_double_range_min:
+ * @value: a GValue initialized to GST_TYPE_DOUBLE_RANGE
  *
+ * Gets the minimum of the range specified by @value.
+ *
+ * Returns: the minumum of the range
  */
 double
 gst_value_get_double_range_min (const GValue * value)
@@ -635,7 +680,11 @@ gst_value_get_double_range_min (const GValue * value)
 
 /**
  * gst_value_get_double_range_max:
+ * @value: a GValue initialized to GST_TYPE_DOUBLE_RANGE
  *
+ * Gets the maximum of the range specified by @value.
+ *
+ * Returns: the maxumum of the range
  */
 double
 gst_value_get_double_range_max (const GValue * value)
@@ -690,7 +739,11 @@ gst_value_deserialize_double_range (GValue * dest, const char *s)
 
 /**
  * gst_value_set_caps:
+ * @value: a GValue initialized to GST_TYPE_CAPS
+ * @caps: the caps to set the value to
  *
+ * Sets the contents of @value to coorespond to @caps.  The actual
+ * #GstCaps structure is copied before it is used.
  */
 void
 gst_value_set_caps (GValue * value, const GstCaps * caps)
@@ -702,7 +755,11 @@ gst_value_set_caps (GValue * value, const GstCaps * caps)
 
 /**
  * gst_value_get_caps:
+ * @value: a GValue initialized to GST_TYPE_CAPS
  *
+ * Gets the contents of @value.
+ *
+ * Returns: the contents of @value
  */
 const GstCaps *
 gst_value_get_caps (const GValue * value)
@@ -712,6 +769,67 @@ gst_value_get_caps (const GValue * value)
   return (GstCaps *) g_value_get_boxed (value);
 }
 
+/*************************************/
+/* GstBuffer */
+
+static char *
+gst_value_serialize_buffer (const GValue * value)
+{
+  guint8 *data;
+  int i;
+  int size;
+  char *string;
+  GstBuffer *buffer = g_value_get_boxed (value);
+
+  data = GST_BUFFER_DATA (buffer);
+  size = GST_BUFFER_SIZE (buffer);
+
+  string = malloc (size * 2 + 1);
+  for (i = 0; i < size; i++) {
+    sprintf (string + i * 2, "%02x", data[i]);
+  }
+  string[size * 2] = 0;
+
+  return string;
+}
+
+static gboolean
+gst_value_deserialize_buffer (GValue * dest, const char *s)
+{
+  GstBuffer *buffer;
+  gboolean ret = TRUE;
+  int len;
+  char ts[3];
+  guint8 *data;
+  int i;
+
+  len = strlen (s);
+  if (len & 1)
+    return FALSE;
+  buffer = gst_buffer_new_and_alloc (len / 2);
+  data = GST_BUFFER_DATA (buffer);
+  for (i = 0; i < len / 2; i++) {
+    if (!isxdigit (s[i * 2]) || !isxdigit (s[i * 2 + 1])) {
+      ret = FALSE;
+      break;
+    }
+    ts[0] = s[i * 2 + 0];
+    ts[1] = s[i * 2 + 1];
+    ts[2] = 0;
+
+    data[i] = strtoul (ts, NULL, 16);
+  }
+
+  if (ret) {
+    g_value_set_boxed (dest, buffer);
+    return TRUE;
+  } else {
+    gst_buffer_unref (buffer);
+    return FALSE;
+  }
+}
+
+
 /*************************************/
 /* boolean */
 
@@ -953,6 +1071,46 @@ gst_value_deserialize_string (GValue * dest, const char *s)
 /*************************************/
 /* unions */
 
+static gboolean
+gst_value_union_int_int_range (GValue * dest, const GValue * src1,
+    const GValue * src2)
+{
+  g_return_val_if_fail (G_VALUE_TYPE (src1) == G_TYPE_INT, FALSE);
+  g_return_val_if_fail (G_VALUE_TYPE (src2) == GST_TYPE_INT_RANGE, FALSE);
+
+  if (src2->data[0].v_int <= src1->data[0].v_int &&
+      src2->data[1].v_int >= src1->data[0].v_int) {
+    gst_value_init_and_copy (dest, src2);
+    return TRUE;
+  }
+
+  return FALSE;
+}
+
+static gboolean
+gst_value_union_int_range_int_range (GValue * dest, const GValue * src1,
+    const GValue * src2)
+{
+  int min;
+  int max;
+
+  g_return_val_if_fail (G_VALUE_TYPE (src1) == GST_TYPE_INT_RANGE, FALSE);
+  g_return_val_if_fail (G_VALUE_TYPE (src2) == GST_TYPE_INT_RANGE, FALSE);
+
+  min = MAX (src1->data[0].v_int, src2->data[0].v_int);
+  max = MIN (src1->data[1].v_int, src2->data[1].v_int);
+
+  if (min <= max) {
+    g_value_init (dest, GST_TYPE_INT_RANGE);
+    gst_value_set_int_range (dest,
+        MIN (src1->data[0].v_int, src2->data[0].v_int),
+        MAX (src1->data[1].v_int, src2->data[1].v_int));
+    return TRUE;
+  }
+
+  return FALSE;
+}
+
 /*************************************/
 /* intersection */
 
@@ -1082,7 +1240,12 @@ gst_value_intersect_list (GValue * dest, const GValue * value1,
 
 /**
  * gst_value_can_compare:
+ * @value1: a value to compare
+ * @value2: another value to compare
  *
+ * Determines if @value1 and @value2 can be compared.
+ *
+ * Returns: TRUE if the values can be compared
  */
 gboolean
 gst_value_can_compare (const GValue * value1, const GValue * value2)
@@ -1103,7 +1266,16 @@ gst_value_can_compare (const GValue * value1, const GValue * value2)
 
 /**
  * gst_value_compare:
+ * @value1: a value to compare
+ * @value2: another value to compare
  *
+ * Compares @value1 and @value2.  If @value1 and @value2 cannot be
+ * compared, the function returns GST_VALUE_UNORDERED.  Otherwise,
+ * if @value1 is greater than @value2, GST_VALUE_GREATER is returned.
+ * If @value1 is less than @value2, GST_VALUE_LESSER is returned.
+ * If the values are equal, GST_VALUE_EQUAL is returned.
+ *
+ * Returns: A GstValueCompareType value
  */
 int
 gst_value_compare (const GValue * value1, const GValue * value2)
@@ -1131,7 +1303,19 @@ gst_value_compare (const GValue * value1, const GValue * value2)
 
 /**
  * gst_value_can_union:
+ * @value1: a value to union
+ * @value2: another value to union
  *
+ * Determines if @value1 and @value2 can be non-trivially unioned.
+ * Any two values can be trivially unioned by adding both of them
+ * to a GstValueList.  However, certain types have the possibility
+ * to be unioned in a simpler way.  For example, an integer range
+ * and an integer can be unioned if the integer is a subset of the
+ * integer range.  If there is the possibility that two values can
+ * be unioned, this function returns TRUE.
+ *
+ * Returns: TRUE if there is a function allowing the two values to
+ * be unioned.
  */
 gboolean
 gst_value_can_union (const GValue * value1, const GValue * value2)
@@ -1144,6 +1328,9 @@ gst_value_can_union (const GValue * value1, const GValue * value2)
     if (union_info->type1 == G_VALUE_TYPE (value1) &&
         union_info->type2 == G_VALUE_TYPE (value2))
       return TRUE;
+    if (union_info->type1 == G_VALUE_TYPE (value2) &&
+        union_info->type2 == G_VALUE_TYPE (value1))
+      return TRUE;
   }
 
   return FALSE;
@@ -1151,7 +1338,13 @@ gst_value_can_union (const GValue * value1, const GValue * value2)
 
 /**
  * gst_value_union:
+ * @dest: the destination value
+ * @value1: a value to union
+ * @value2: another value to union
  *
+ * Creates a GValue cooresponding to the union of @value1 and @value2.
+ *
+ * Returns: TRUE if the values could be unioned
  */
 gboolean
 gst_value_union (GValue * dest, const GValue * value1, const GValue * value2)
@@ -1163,7 +1356,15 @@ gst_value_union (GValue * dest, const GValue * value1, const GValue * value2)
     union_info = &g_array_index (gst_value_union_funcs, GstValueUnionInfo, i);
     if (union_info->type1 == G_VALUE_TYPE (value1) &&
         union_info->type2 == G_VALUE_TYPE (value2)) {
-      return union_info->func (dest, value1, value2);
+      if (union_info->func (dest, value1, value2)) {
+        return TRUE;
+      }
+    }
+    if (union_info->type1 == G_VALUE_TYPE (value2) &&
+        union_info->type2 == G_VALUE_TYPE (value1)) {
+      if (union_info->func (dest, value2, value1)) {
+        return TRUE;
+      }
     }
   }
 
@@ -1173,6 +1374,12 @@ gst_value_union (GValue * dest, const GValue * value1, const GValue * value2)
 
 /**
  * gst_value_register_union_func:
+ * @type1: a type to union
+ * @type2: another type to union
+ * @func: a function that implments creating a union between the two types
+ *
+ * Registers a union function that can create a union between GValues
+ * of the type @type1 and @type2.
  *
  */
 void
@@ -1189,9 +1396,12 @@ gst_value_register_union_func (GType type1, GType type2, GstValueUnionFunc func)
 
 /* intersection */
 
-/**
+/*
  * gst_value_can_intersect:
+ * @value1:
+ * @value2:
  *
+ * Returns:
  */
 gboolean
 gst_value_can_intersect (const GValue * value1, const GValue * value2)
@@ -1216,7 +1426,13 @@ gst_value_can_intersect (const GValue * value1, const GValue * value2)
 
 /**
  * gst_value_intersect:
+ * @dest: the destination value for intersection
+ * @value1: a value to intersect
+ * @value2: another value to intersect
  *
+ * Calculates the intersection of the two values.
+ *
+ * Returns: TRUE if the intersection is non-empty
  */
 gboolean
 gst_value_intersect (GValue * dest, const GValue * value1,
@@ -1257,6 +1473,9 @@ gst_value_intersect (GValue * dest, const GValue * value1,
 
 /**
  * gst_value_register_intersection_func:
+ * @type1:
+ * @type2:
+ * @func:
  *
  */
 void
@@ -1272,8 +1491,9 @@ gst_value_register_intersect_func (GType type1, GType type2,
   g_array_append_val (gst_value_intersect_funcs, intersect_info);
 }
 
-/**
+/*
  * gst_value_register:
+ * @table:
  *
  */
 void
@@ -1282,8 +1502,10 @@ gst_value_register (const GstValueTable * table)
   g_array_append_val (gst_value_table, *table);
 }
 
-/**
+/*
  * gst_value_init_and_copy:
+ * @dest:
+ * @src:
  *
  */
 void
@@ -1293,9 +1515,11 @@ gst_value_init_and_copy (GValue * dest, const GValue * src)
   g_value_copy (src, dest);
 }
 
-/**
+/*
  * gst_value_serialize:
+ * @value:
  *
+ * Returns:
  */
 gchar *
 gst_value_serialize (const GValue * value)
@@ -1321,9 +1545,12 @@ gst_value_serialize (const GValue * value)
   return s;
 }
 
-/**
+/*
  * gst_value_deserialize:
+ * @dest:
+ * @src:
  *
+ * Returns:
  */
 gboolean
 gst_value_deserialize (GValue * dest, const gchar * src)
@@ -1357,6 +1584,7 @@ _gst_value_initialize (void)
     NULL,
     NULL,
   };
+
   //const GTypeFundamentalInfo finfo = { G_TYPE_FLAG_DERIVABLE, };
 
   gst_value_table = g_array_new (FALSE, FALSE, sizeof (GstValueTable));
@@ -1382,6 +1610,7 @@ _gst_value_initialize (void)
       gst_value_serialize_fourcc,
       gst_value_deserialize_fourcc,
     };
+
     info.value_table = &value_table;
     gst_type_fourcc =
         g_type_register_static (G_TYPE_BOXED, "GstFourcc", &info, 0);
@@ -1406,6 +1635,7 @@ _gst_value_initialize (void)
       gst_value_serialize_int_range,
       gst_value_deserialize_int_range,
     };
+
     info.value_table = &value_table;
     gst_type_int_range =
         g_type_register_static (G_TYPE_BOXED, "GstIntRange", &info, 0);
@@ -1430,6 +1660,7 @@ _gst_value_initialize (void)
       gst_value_serialize_double_range,
       gst_value_deserialize_double_range,
     };
+
     info.value_table = &value_table;
     gst_type_double_range =
         g_type_register_static (G_TYPE_BOXED, "GstDoubleRange", &info, 0);
@@ -1454,6 +1685,7 @@ _gst_value_initialize (void)
       gst_value_serialize_list,
       gst_value_deserialize_list,
     };
+
     info.value_table = &value_table;
     gst_type_list =
         g_type_register_static (G_TYPE_BOXED, "GstValueList", &info, 0);
@@ -1461,6 +1693,35 @@ _gst_value_initialize (void)
     gst_value_register (&gst_value);
   }
 
+  {
+#if 0
+    static const GTypeValueTable value_table = {
+      gst_value_init_buffer,
+      NULL,
+      gst_value_copy_buffer,
+      NULL,
+      "i",
+      NULL,                     /*gst_value_collect_buffer, */
+      "p",
+      NULL                      /*gst_value_lcopy_buffer */
+    };
+#endif
+    static GstValueTable gst_value = {
+      0,
+      NULL,                     /*gst_value_compare_buffer, */
+      gst_value_serialize_buffer,
+      gst_value_deserialize_buffer,
+    };
+
+#if 0
+    info.value_table = &value_table;
+    gst_type_fourcc =
+        g_type_register_static (G_TYPE_BOXED, "GstFourcc", &info, 0);
+#endif
+    gst_value.type = GST_TYPE_BUFFER;
+    gst_value_register (&gst_value);
+  }
+
   {
     static const GstValueTable gst_value = {
       G_TYPE_INT,
@@ -1468,6 +1729,7 @@ _gst_value_initialize (void)
       gst_value_serialize_int,
       gst_value_deserialize_int,
     };
+
     gst_value_register (&gst_value);
   }
 
@@ -1478,6 +1740,7 @@ _gst_value_initialize (void)
       gst_value_serialize_double,
       gst_value_deserialize_double,
     };
+
     gst_value_register (&gst_value);
   }
 
@@ -1488,6 +1751,7 @@ _gst_value_initialize (void)
       gst_value_serialize_string,
       gst_value_deserialize_string,
     };
+
     gst_value_register (&gst_value);
   }
 
@@ -1498,6 +1762,7 @@ _gst_value_initialize (void)
       gst_value_serialize_boolean,
       gst_value_deserialize_boolean,
     };
+
     gst_value_register (&gst_value);
   }
 
@@ -1518,4 +1783,9 @@ _gst_value_initialize (void)
       gst_value_intersect_double_double_range);
   gst_value_register_intersect_func (GST_TYPE_DOUBLE_RANGE,
       GST_TYPE_DOUBLE_RANGE, gst_value_intersect_double_range_double_range);
+
+  gst_value_register_union_func (G_TYPE_INT, GST_TYPE_INT_RANGE,
+      gst_value_union_int_int_range);
+  gst_value_register_union_func (GST_TYPE_INT_RANGE, GST_TYPE_INT_RANGE,
+      gst_value_union_int_range_int_range);
 }
