@@ -30,6 +30,7 @@
 #include <sys/stat.h>
 #include <dirent.h>
 #include <unistd.h>
+#include <fcntl.h>
 #include <utime.h>
 
 #include <gst/gst_private.h>
@@ -141,6 +142,7 @@ gst_xml_registry_get_type (void)
       (GInstanceInitFunc) gst_xml_registry_init,
       NULL
     };
+
     xml_registry_type = g_type_register_static (GST_TYPE_REGISTRY,
         "GstXMLRegistry", &xml_registry_info, 0);
   }
@@ -281,19 +283,25 @@ gst_xml_registry_get_property (GObject * object, guint prop_id,
  * so this function returns the last time *anything* changed to this path
  */
 static time_t
-get_time (const char *path)
+get_time (const char *path, gboolean * is_dir)
 {
   struct stat statbuf;
 
-  if (stat (path, &statbuf))
+  if (stat (path, &statbuf)) {
+    *is_dir = FALSE;
     return 0;
+  }
+
+  if (is_dir)
+    *is_dir = S_ISDIR (statbuf.st_mode);
+
   if (statbuf.st_mtime > statbuf.st_ctime)
     return statbuf.st_mtime;
   return statbuf.st_ctime;
 }
 
 /* same as 0755 */
-#define dirmode \
+#define DIRMODE \
   (S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH)
 
 static gboolean
@@ -308,15 +316,19 @@ make_dir (gchar * filename)
   dirname = g_strndup (filename, strrchr (filename, '/') - filename);
 
   if (stat (dirname, &dirstat) == -1 && errno == ENOENT) {
-    if (mkdir (dirname, dirmode) != 0) {
+#ifndef HAVE_WIN32
+    if (mkdir (dirname, DIRMODE) != 0) {
       if (make_dir (dirname) != TRUE) {
         g_free (dirname);
         return FALSE;
       } else {
-        if (mkdir (dirname, dirmode) != 0)
+        if (mkdir (dirname, DIRMODE) != 0)
           return FALSE;
       }
     }
+#else
+    return FALSE;
+#endif
   }
 
   g_free (dirname);
@@ -326,8 +338,7 @@ make_dir (gchar * filename)
 static void
 gst_xml_registry_get_perms_func (GstXMLRegistry * registry)
 {
-  time_t mod_time = 0;
-  FILE *temp;
+  gchar *dirname;
 
   /* if the dir does not exist, make it. if that can't be done, flags = 0x0.
      if the file can be appended to, it's writable. if it can then be read,
@@ -339,33 +350,21 @@ gst_xml_registry_get_perms_func (GstXMLRegistry * registry)
     return;
   }
 
-  mod_time = get_time (registry->location);
-
-  if ((temp = fopen (registry->location, "a"))) {
-    GST_REGISTRY (registry)->flags |= GST_REGISTRY_WRITABLE;
-    fclose (temp);
-  }
-
-  if ((temp = fopen (registry->location, "r"))) {
-    GST_REGISTRY (registry)->flags |= GST_REGISTRY_READABLE;
-    fclose (temp);
-  }
+  dirname = g_path_get_dirname (registry->location);
 
   if (g_file_test (registry->location, G_FILE_TEST_EXISTS)) {
     GST_REGISTRY (registry)->flags |= GST_REGISTRY_EXISTS;
   }
 
-  if (mod_time) {
-    struct utimbuf utime_buf;
-
-    /* set the modification time back to its previous value */
-    utime_buf.actime = mod_time;
-    utime_buf.modtime = mod_time;
-    utime (registry->location, &utime_buf);
-  } else if (GST_REGISTRY (registry)->flags & GST_REGISTRY_WRITABLE) {
-    /* it did not exist before, so delete it */
-    unlink (registry->location);
+  if (!access (dirname, W_OK)) {
+    GST_REGISTRY (registry)->flags |= GST_REGISTRY_WRITABLE;
   }
+
+  if (!access (dirname, R_OK)) {
+    GST_REGISTRY (registry)->flags |= GST_REGISTRY_READABLE;
+  }
+
+  g_free (dirname);
 }
 
 static void
@@ -419,9 +418,10 @@ plugin_times_older_than_recurse (gchar * path, time_t regtime)
 {
   DIR *dir;
   struct dirent *dirent;
+  gboolean is_dir;
   gchar *pluginname;
 
-  time_t pathtime = get_time (path);
+  time_t pathtime = get_time (path, &is_dir);
 
   if (pathtime > regtime) {
     GST_CAT_INFO (GST_CAT_PLUGIN_LOADING,
@@ -430,6 +430,9 @@ plugin_times_older_than_recurse (gchar * path, time_t regtime)
     return FALSE;
   }
 
+  if (!is_dir)
+    return TRUE;
+
   dir = opendir (path);
   if (dir) {
     while ((dirent = readdir (dir))) {
@@ -501,7 +504,7 @@ gst_xml_registry_open_func (GstXMLRegistry * registry, GstXMLRegistryMode mode)
     /* at this point we know it exists */
     g_return_val_if_fail (gst_registry->flags & GST_REGISTRY_READABLE, FALSE);
 
-    if (!plugin_times_older_than (paths, get_time (registry->location))) {
+    if (!plugin_times_older_than (paths, get_time (registry->location, NULL))) {
       if (gst_registry->flags & GST_REGISTRY_WRITABLE) {
         GST_CAT_INFO (GST_CAT_GST_INIT, "Registry out of date, rebuilding...");
 
@@ -509,7 +512,8 @@ gst_xml_registry_open_func (GstXMLRegistry * registry, GstXMLRegistryMode mode)
 
         gst_registry_save (gst_registry);
 
-        if (!plugin_times_older_than (paths, get_time (registry->location))) {
+        if (!plugin_times_older_than (paths, get_time (registry->location,
+                    NULL))) {
           GST_CAT_INFO (GST_CAT_GST_INIT,
               "Registry still out of date, something is wrong...");
           return FALSE;
@@ -525,11 +529,22 @@ gst_xml_registry_open_func (GstXMLRegistry * registry, GstXMLRegistryMode mode)
         registry->location);
     registry->regfile = fopen (registry->location, "r");
   } else if (mode == GST_XML_REGISTRY_WRITE) {
+    char *tmploc;
+    int fd;
+
     g_return_val_if_fail (gst_registry->flags & GST_REGISTRY_WRITABLE, FALSE);
 
-    GST_CAT_DEBUG (GST_CAT_GST_INIT, "opening registry %s for writing",
-        registry->location);
-    registry->regfile = fopen (registry->location, "w");
+    tmploc = g_strconcat (registry->location, ".tmp", NULL);
+
+    GST_CAT_DEBUG (GST_CAT_GST_INIT, "opening registry %s for writing", tmploc);
+
+    if ((fd = open (tmploc, O_WRONLY | O_CREAT | O_EXCL, 0644)) < 0) {
+      g_free (tmploc);
+      return FALSE;
+    }
+    g_free (tmploc);
+
+    registry->regfile = fdopen (fd, "w");
   }
 
   if (!registry->regfile)
@@ -566,9 +581,17 @@ gst_xml_registry_save_func (GstXMLRegistry * registry, gchar * format, ...)
 static gboolean
 gst_xml_registry_close_func (GstXMLRegistry * registry)
 {
+  char *tmploc;
+
   GST_CAT_DEBUG (GST_CAT_GST_INIT, "closing registry %s", registry->location);
   fclose (registry->regfile);
 
+  /* If we opened for writing, rename our temporary file. */
+  tmploc = g_strconcat (registry->location, ".tmp", NULL);
+  if (g_file_test (tmploc, G_FILE_TEST_EXISTS))
+    rename (tmploc, registry->location);
+  g_free (tmploc);
+
   registry->open = FALSE;
 
   return TRUE;
@@ -1292,8 +1315,8 @@ gst_xml_registry_rebuild_recurse (GstXMLRegistry * registry,
     const gchar * directory)
 {
   GDir *dir;
-  gchar *temp;
   GList *ret = NULL;
+  gint dr_len, sf_len;
 
   dir = g_dir_open (directory, 0, NULL);
 
@@ -1316,8 +1339,10 @@ gst_xml_registry_rebuild_recurse (GstXMLRegistry * registry,
     }
     g_dir_close (dir);
   } else {
-    if ((temp = strstr (directory, G_MODULE_SUFFIX)) &&
-        (!strcmp (temp, G_MODULE_SUFFIX))) {
+    dr_len = strlen (directory);
+    sf_len = strlen (G_MODULE_SUFFIX);
+    if (dr_len >= sf_len &&
+        strcmp (directory + dr_len - sf_len, G_MODULE_SUFFIX) == 0) {
       ret = g_list_prepend (ret, g_strdup (directory));
     }
   }
