@@ -21,8 +21,10 @@
  */
 
 #include <glib.h>
+#include <gst/gstthread.h>
 
 /* the name of this cothreads */
+#define COTHREADS_TYPE		gthread
 #define COTHREADS_NAME		"gthread"
 #define COTHREADS_NAME_CAPITAL	"GThread"
 
@@ -34,7 +36,7 @@
  */
 
 /* define "cothread", "cothread_context" and "cothread_func" */
-typedef void (*cothread_func) (int, char **);
+typedef int (*cothread_func) (int, char **);
 
 typedef struct _cothread cothread;
 typedef struct _cothread_context cothread_context;
@@ -44,6 +46,7 @@ struct _cothread_context {
   cothread *            main;
   cothread *            current;
   GMutex *              mutex;
+  GstThread *		gst_thread; /* the GstThread we're running from */
 };
 
 struct _cothread {
@@ -72,14 +75,7 @@ static cothread *       cothread_create                 (cothread_context *conte
     new_cothread = cothread_create ((context), (func), argc, (char**) (argv)); \
   }G_STMT_END
 static void             do_cothread_switch              (cothread *to);
-static void             do_cothread_setfunc             (cothread *thread, 
-                                                         cothread_context *context, 
-                                                         cothread_func func, 
-                                                         int argc, 
-                                                         char **argv);
 static void             do_cothread_destroy             (cothread *thread);
-#define do_cothread_lock(cothread)		/* FIXME */
-#define do_cothread_unlock(cothread)		/* FIXME */
 #define do_cothread_get_current(context) ((context)->current)
 #define do_cothread_get_main(context) ((context)->main)
 
@@ -101,6 +97,7 @@ do_cothread_context_init (void)
   ret->mutex = g_mutex_new ();
   ret->cothreads = NULL;
   ret->current = ret->main;
+  ret->gst_thread = gst_thread_get_current();
   g_mutex_lock (ret->mutex);
   
   return ret;
@@ -132,6 +129,7 @@ run_new_thread (gpointer data)
   cothread *self = (cothread *) data;
   
   g_mutex_lock (self->context->mutex);
+  g_private_set (gst_thread_current, self->context->gst_thread);
   g_cond_signal (self->creator->cond);
   g_cond_wait (self->cond, self->context->mutex);
   if (self->die)
@@ -176,9 +174,7 @@ static void do_cothread_switch (cothread *to)
 {
   cothread *self = do_cothread_get_current(to->context);
   
-  if (self == to) {
-    g_warning ("trying to switch to the same cothread, not allowed");
-  } else {
+  if (self != to) {
     self->context->current = to;
     g_cond_signal (to->cond);
     g_cond_wait (self->cond, self->context->mutex);
@@ -187,14 +183,12 @@ static void do_cothread_switch (cothread *to)
   }
 }
 
-static void
-do_cothread_setfunc (cothread *thread, cothread_context *context, 
-                     cothread_func func, int argc, char **argv)
-{
-  thread->run = func;
-  thread->argc = argc;
-  thread->argv = argv;
-}
+#define do_cothread_setfunc(thread,context,_func,_argc,_argv) G_STMT_START {\
+  ((cothread *)(thread))->run = (_func); \
+  ((cothread *)(thread))->argc = _argc; \
+  ((cothread *)(thread))->argv = _argv; \
+}G_STMT_END
+
 static void
 do_cothread_destroy (cothread *thread)
 {
@@ -212,8 +206,5 @@ do_cothread_destroy (cothread *thread)
   /* the mutex was locked by the thread that we joined, no need to lock again */
 }
   
-#define do_cothread_lock(cothread)		/* FIXME */
-#define do_cothread_unlock(cothread)		/* FIXME */
-
 #define do_cothread_get_current(context) ((context)->current)
 #define do_cothread_get_main(context) ((context)->main)
